@@ -25,7 +25,7 @@
 #include <KMessageBox>
 
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 const QString AdaWriter::defaultPackageSuffix = QStringLiteral("_Holder");
@@ -116,12 +116,12 @@ QString AdaWriter::packageName(UMLPackage *p)
     QString retval;
 
     if (umlPkg == UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical))
-        umlPkg = 0;
+        umlPkg = nullptr;
 
     const UMLClassifier *c = p->asUMLClassifier();
-    if (umlPkg == 0) {
+    if (umlPkg == nullptr) {
         retval = className;
-        if (c == 0 || !isOOClass(c))
+        if (c == nullptr || !isOOClass(c))
             retval.append(defaultPackageSuffix);
     } else {
         retval = umlPkg->fullyQualifiedName(QStringLiteral("."));
@@ -142,14 +142,14 @@ void AdaWriter::computeAssocTypeAndRole(UMLClassifier *c,
                                         QString& typeName, QString& roleName)
 {
     UMLClassifier* assocEnd = a->getObject(Uml::RoleType::B)->asUMLClassifier();
-    if (assocEnd == 0)
+    if (assocEnd == nullptr)
         return;
     const Uml::AssociationType::Enum assocType = a->getAssocType();
     if (assocType != Uml::AssociationType::Aggregation && assocType != Uml::AssociationType::Composition)
         return;
     const QString multi = a->getMultiplicity(Uml::RoleType::B);
     bool hasNonUnityMultiplicity = (!multi.isEmpty() && multi != QStringLiteral("1"));
-    hasNonUnityMultiplicity &= !multi.contains(QRegExp(QStringLiteral("^1 *\\.\\. *1$")));
+    hasNonUnityMultiplicity &= !multi.contains(QRegularExpression(QStringLiteral("^1 *\\.\\. *1$")));
     roleName = cleanName(a->getRoleName(Uml::RoleType::B));
     if (roleName.isEmpty())
         roleName = cleanName(a->name());
@@ -173,15 +173,15 @@ void AdaWriter::computeAssocTypeAndRole(UMLClassifier *c,
 void AdaWriter::declareClass(UMLClassifier *c, QTextStream &ada)
 {
     UMLClassifierList superclasses = c->getSuperClasses();
-    UMLClassifier *firstSuperClass = 0;
+    UMLClassifier *firstSuperClass = nullptr;
     if (!superclasses.isEmpty()) {
-        foreach (UMLClassifier* super, superclasses) {
+        for(UMLClassifier* super : superclasses) {
             if (!super->isInterface()) {
                 firstSuperClass = super;
                 break;
             }
         }
-        if (firstSuperClass == 0)
+        if (firstSuperClass == nullptr)
             firstSuperClass = superclasses.first();
     }
     const QString name = className(c);
@@ -192,7 +192,7 @@ void AdaWriter::declareClass(UMLClassifier *c, QTextStream &ada)
         ada << "tagged ";
     } else {
         ada << "new " << className(firstSuperClass, false);
-        foreach (UMLClassifier* super, superclasses) {
+        for(UMLClassifier* super : superclasses) {
             if (super->isInterface() && super != firstSuperClass)
                 ada << " and " << className(super, false);
         }
@@ -222,11 +222,11 @@ void AdaWriter::writeClass(UMLClassifier *c)
     //find an appropriate name for our file
     fileName = overwritableName(c, fileName, QStringLiteral(".ads"));
     if (fileName.isEmpty()) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
-    QFile *file = 0;
+    QFile *file = nullptr;
     bool isNewFile = false;
     PackageFileMap::iterator it = m_pkgsGenerated.find(pkg);
     if (it != m_pkgsGenerated.end()) {
@@ -234,7 +234,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     } else {
         file = new QFile();
         if (!openFile(*file, fileName)) {
-            emit codeGenerated(c, false);
+            Q_EMIT codeGenerated(c, false);
             delete file;
             return;
         }
@@ -250,8 +250,8 @@ void AdaWriter::writeClass(UMLClassifier *c)
         QString str;
         str = getHeadingFile(QStringLiteral(".ads"));
         if (!str.isEmpty()) {
-            str.replace(QRegExp(QStringLiteral("%filename%")), fileName);
-            str.replace(QRegExp(QStringLiteral("%filepath%")), file->fileName());
+            str.replace(QRegularExpression(QStringLiteral("%filename%")), fileName);
+            str.replace(QRegularExpression(QStringLiteral("%filepath%")), file->fileName());
             ada << str << m_endl;
         }
 
@@ -259,7 +259,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
         UMLPackageList imports;
         findObjectsRelated(c, imports);
         if (imports.count()) {
-            foreach (UMLPackage* con, imports) {
+            for(UMLPackage* con : imports) {
                 if (con->isUMLDatatype())
                     continue;
                 QString pkgDep = packageName(con);
@@ -274,7 +274,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
         if (template_params.count()) {
             ada << indent() << "generic" << m_endl;
             m_indentLevel++;
-            foreach (UMLTemplate* t, template_params) {
+            for(UMLTemplate* t : template_params) {
                 QString formalName = t->name();
                 QString typeName = t->getTypeName();
                 if (typeName == QStringLiteral("class")) {
@@ -283,7 +283,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
                 } else {
                     // Check whether it's a data type.
                     UMLClassifier *typeObj = t->getType();
-                    if (typeObj == 0) {
+                    if (typeObj == nullptr) {
                         logError1("template_param %1: typeObj is NULL", typeName);
                         ada << indent() << "type " << formalName << " is new " << typeName
                             << " with private;  -- CHECK: codegen error"
@@ -310,7 +310,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
         uint i = 0;
         ada << indent() << "type " << classname << " is (" << m_endl;
         m_indentLevel++;
-        foreach (UMLClassifierListItem* lit, litList) {
+        for(UMLClassifierListItem* lit : litList) {
             QString enumLiteral = cleanName(lit->name());
             ada << indent() << enumLiteral;
             if (++i < (uint)litList.count())
@@ -330,7 +330,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
                 UMLAttributeList atl = c->getAttributeList();
                 ada << indent() << "type " << classname << " is record" << m_endl;
                 m_indentLevel++;
-                foreach (UMLAttribute* at,  atl) {
+                for(UMLAttribute* at :  atl) {
                     QString name = cleanName(at->name());
                     QString typeName = at->getTypeName();
                     ada << indent() << name << " : " << typeName;
@@ -356,7 +356,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     UMLClassifierList superclasses = c->getSuperClasses();
     if (!superclasses.isEmpty()) {
         // Ensure that superclasses in same package are declared before this class.
-        foreach (UMLClassifier* super, superclasses) {
+        for(UMLClassifier* super : superclasses) {
             if (packageName(super) == pkg && !m_classesGenerated.contains(super)) {
                 writeClass(super);
             }
@@ -378,7 +378,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
         ada << "private;" << m_endl << m_endl;
     } else {
         ada << indent() << "type " << name << " is interface";
-        foreach (UMLClassifier* super, superclasses) {
+        for(UMLClassifier* super : superclasses) {
             if (super->isInterface())
                 ada << " and " << className(super, false);
         }
@@ -395,14 +395,14 @@ void AdaWriter::writeClass(UMLClassifier *c)
 
         atl = c->getAttributeList();
 
-        foreach (UMLAttribute* at, atl) {
+        for(UMLAttribute* at : atl) {
             if (at->visibility() == Uml::Visibility::Public)
                 atpub.append(at);
         }
         if (forceSections() || atpub.count())
             ada << indent() << "-- Accessors for public attributes:" << m_endl << m_endl;
 
-        foreach (UMLAttribute* at, atpub) {
+        for(UMLAttribute* at : atpub) {
             QString member = cleanName(at->name());
             ada << indent() << "procedure Set_" << member << " (";
             if (! at->isStatic())
@@ -418,18 +418,18 @@ void AdaWriter::writeClass(UMLClassifier *c)
     // Generate public operations.
     UMLOperationList opl(c->getOpList());
     UMLOperationList oppub;
-    foreach (UMLOperation* op, opl) {
+    for(UMLOperation* op : opl) {
         if (op->visibility() == Uml::Visibility::Public)
             oppub.append(op);
     }
     if (forceSections() || oppub.count())
         ada << indent() << "-- Public methods:" << m_endl << m_endl;
 
-    foreach (UMLOperation* op, oppub) {
+    for(UMLOperation* op : oppub) {
         writeOperation(op, ada);
     }
 
-    emit codeGenerated(c, true);
+    Q_EMIT codeGenerated(c, true);
 }
 
 /**
@@ -463,7 +463,7 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
     if (atl.count()) {
         uint i = 0;
         m_indentLevel++;
-        foreach (UMLAttribute* at, atl) {
+        for(UMLAttribute* at : atl) {
             ada << indent();
             if (is_comment)
                 ada << "-- ";
@@ -669,7 +669,7 @@ void AdaWriter::finalizeRun()
         QFile *file = i.value();
         QTextStream ada(file);
         ada << m_endl << "private" << m_endl << m_endl;
-        foreach (UMLClassifier* c, m_classesGenerated) {
+        for(UMLClassifier* c : m_classesGenerated) {
             if (packageName(c) != pkg)
                 continue;
             bool isClass = !c->isInterface();
@@ -683,7 +683,7 @@ void AdaWriter::finalizeRun()
 
                 if (forceSections() || !aggregations.isEmpty()) {
                     ada << indent() << "-- Aggregations:" << m_endl;
-                    foreach (UMLAssociation *a, aggregations) {
+                    for(UMLAssociation *a : aggregations) {
                         if (c != a->getObject(Uml::RoleType::A))
                             continue;
                         QString typeName, roleName;
@@ -694,7 +694,7 @@ void AdaWriter::finalizeRun()
                 }
                 if (forceSections() || !compositions.isEmpty()) {
                     ada << indent() << "-- Compositions:" << m_endl;
-                    foreach (UMLAssociation *a, compositions) {
+                    for(UMLAssociation *a : compositions) {
                         if (c != a->getObject(Uml::RoleType::A))
                             continue;
                         QString typeName, roleName;
@@ -707,7 +707,7 @@ void AdaWriter::finalizeRun()
                 UMLAttributeList atl = c->getAttributeList();
                 if (forceSections() || atl.count()) {
                     ada << indent() << "-- Attributes:" << m_endl;
-                    foreach (UMLAttribute* at, atl) {
+                    for(UMLAttribute* at : atl) {
                         if (!at || at->isStatic())
                             continue;
                         ada << indent() << cleanName(at->name()) << " : "
@@ -724,7 +724,7 @@ void AdaWriter::finalizeRun()
                 ada << indent() << "end record;" << m_endl << m_endl;
                 if (haveAttrs) {
                     bool seen_static_attr = false;
-                    foreach (UMLAttribute* at, atl) {
+                    for(UMLAttribute* at : atl) {
                         if (! at->isStatic())
                             continue;
                         if (! seen_static_attr) {
@@ -746,13 +746,13 @@ void AdaWriter::finalizeRun()
             UMLOperationList opl(c->getOpList());
             // Generate protected operations.
             UMLOperationList opprot;
-            foreach (UMLOperation* op,  opl) {
+            for(UMLOperation* op : opl) {
                 if (op->visibility() == Uml::Visibility::Protected)
                     opprot.append(op);
             }
             if (forceSections() || opprot.count())
                 ada << indent() << "-- Protected methods:" << m_endl << m_endl;
-            foreach (UMLOperation* op, opprot) {
+            for(UMLOperation* op : opprot) {
                 writeOperation(op, ada);
             }
 
@@ -763,7 +763,7 @@ void AdaWriter::finalizeRun()
             // hand written code sections, private operations should be generated
             // into the package body.
             UMLOperationList oppriv;
-            foreach (UMLOperation* op, opl) {
+            for(UMLOperation* op : opl) {
                 const Uml::Visibility::Enum vis = op->visibility();
                 if (vis == Uml::Visibility::Private ||
                     vis == Uml::Visibility::Implementation)
@@ -771,13 +771,13 @@ void AdaWriter::finalizeRun()
             }
             if (forceSections() || oppriv.count())
                 ada << indent() << "-- Private methods:" << m_endl << m_endl;
-            foreach (UMLOperation* op, oppriv) {
+            for(UMLOperation* op : oppriv) {
                 writeOperation(op, ada, true);
             }
         }
         ada << m_endl << "end " << i.key() << ";" << m_endl;
         file->close();
-        emit showGeneratedFile(file->fileName());
+        Q_EMIT showGeneratedFile(file->fileName());
         delete file;
     }
 }
