@@ -20,7 +20,7 @@
 #include "uml.h"
 
 // qt includes
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QXmlStreamWriter>
 
 /**
@@ -49,7 +49,7 @@ CodeClassField::CodeClassField (ClassifierCodeDocument * doc, UMLAttribute * att
 CodeClassField::~CodeClassField ()
 {
     // remove methods from parent document
-    Q_FOREACH(CodeAccessorMethod *m, m_methodVector)
+    for(CodeAccessorMethod *m : m_methodVector)
     {
         getParentDocument()->removeTextBlock(m);
         m->forceRelease();
@@ -247,7 +247,7 @@ void CodeClassField::setAttributesOnNode (QXmlStreamWriter& writer)
     m_declCodeBlock->saveToXMI(writer);
 
     // now record the tags on our accessormethods
-    Q_FOREACH(CodeAccessorMethod *method, m_methodVector)
+    for(CodeAccessorMethod *method : m_methodVector)
     {
         method->saveToXMI(writer);
     }
@@ -336,8 +336,8 @@ int CodeClassField::minimumListOccurances()
         // ush. IF we had a multiplicity object, this would be much easier.
         if (!multi.isEmpty())
         {
-            QString lowerBoundString = multi.remove(QRegExp(QStringLiteral("\\.\\.\\d+$")));
-            if(!lowerBoundString.isEmpty() &&lowerBoundString.contains(QRegExp(QStringLiteral("^\\d+$"))))
+            QString lowerBoundString = multi.remove(QRegularExpression(QStringLiteral("\\.\\.\\d+$")));
+            if(!lowerBoundString.isEmpty() &&lowerBoundString.contains(QRegularExpression(QStringLiteral("^\\d+$"))))
                 return lowerBoundString.toInt();
         }
 
@@ -364,8 +364,8 @@ int CodeClassField::maximumListOccurances()
         // ush. IF we had a multiplicity object, this would be much easier.
         if (!multi.isEmpty())
         {
-            QString upperBoundString = multi.section(QRegExp(QStringLiteral("(\\.\\.)")), 1);
-            if (!upperBoundString.isEmpty() && upperBoundString.contains(QRegExp(QStringLiteral("^\\d+$"))))
+            QString upperBoundString = multi.section(QRegularExpression(QStringLiteral("(\\.\\.)")), 1);
+            if (!upperBoundString.isEmpty() && upperBoundString.contains(QRegularExpression(QStringLiteral("^\\d+$"))))
                 return upperBoundString.toInt();
             else
                 return -1; // unbounded
@@ -409,8 +409,9 @@ QString CodeClassField::fixInitialStringDeclValue(const QString& val, const QStr
 void CodeClassField::synchronize ()
 {
     updateContent();
-    Q_FOREACH(CodeAccessorMethod *method, m_methodVector)
+    for(CodeAccessorMethod *method : m_methodVector) {
         method->syncToParent();
+    }
 
     if(m_declCodeBlock)
         m_declCodeBlock->syncToParent();
@@ -427,17 +428,17 @@ CodeAccessorMethod * CodeClassField::findMethodByType (CodeAccessorMethod::Acces
         // argh. this wont work because "accessorType' doesn't inherit from QObject.
         if(m_methodMap->contains(type))
                 return ((*m_methodMap)[type]);
-        CodeAccessorMethod * obj = 0;
+        CodeAccessorMethod *obj = nullptr;
     */
     if(role_id > 1 || role_id < 0)
     {
-        Q_FOREACH(CodeAccessorMethod *m, m_methodVector)
+        for(CodeAccessorMethod  *m : m_methodVector)
             if(m->getType() == type)
                 return m;
     } else {
         // ugh. forced into this underperforming algorithm because of bad association
         // design.
-        Q_FOREACH(CodeAccessorMethod *m, m_methodVector)
+        for(CodeAccessorMethod  *m : m_methodVector)
         {
             const UMLRole * role = m->getParentObject()->asUMLRole();
             if(!role)
@@ -520,8 +521,9 @@ void CodeClassField::updateContent()
     // all here? -b.t.
     if (parentIsAttribute())
     {
-        Q_FOREACH(CodeAccessorMethod *method, m_methodVector)
+        for(CodeAccessorMethod *method : m_methodVector) {
             method->setWriteOutText(m_writeOutMethods);
+        }
         return;
     }
     const UMLRole * role = getParentObject()->asUMLRole();
@@ -531,7 +533,7 @@ void CodeClassField::updateContent()
     bool isSingleValue = fieldIsSingleValue();
     bool isEmptyRole = role->name().isEmpty() ? true : false;
 
-    Q_FOREACH(CodeAccessorMethod *method, m_methodVector)
+    for(CodeAccessorMethod *method : m_methodVector)
     {
 
         CodeAccessorMethod::AccessorType type = method->getType();
@@ -625,8 +627,8 @@ bool CodeClassField::fieldIsSingleValue ()
 
     QString multi = role->multiplicity();
 
-    if(multi.isEmpty() || multi.contains(QRegExp(QStringLiteral("^(0|1)$")))
-            || multi.contains(QRegExp(QStringLiteral("^0\\.\\.1$"))))
+    if(multi.isEmpty() || multi.contains(QRegularExpression(QStringLiteral("^(0|1)$")))
+            || multi.contains(QRegularExpression(QStringLiteral("^0\\.\\.1$"))))
         return true;
 
     return false;
@@ -639,7 +641,7 @@ void CodeClassField::initFields(bool inConstructor)
 {
     m_writeOutMethods = false;
     m_listClassName.clear();
-    m_declCodeBlock = 0;
+    m_declCodeBlock = nullptr;
 
     // m_methodMap = new QMap<CodeAccessorMethod::AccessorType, CodeAccessorMethod *>;
 
