@@ -18,7 +18,7 @@ class CPPCodeGenerationForm : public QWidget, private Ui::CPPCodeGenerationFormB
     Q_OBJECT
 public:
 
-    explicit CPPCodeGenerationForm (QWidget *parent = 0, const char *name = 0);
+    explicit CPPCodeGenerationForm (QWidget   *parent = nullptr, const char *name = nullptr);
     virtual ~CPPCodeGenerationForm();
 
     void setPackageIsANamespace(bool bFlag = true);
@@ -49,11 +49,11 @@ public:
     bool getAccessorMethodsStartWithUpperCase();
     QString getClassMemberPrefix();
 
-public slots:
+public Q_SLOTS:
 
     virtual void browseClicked();
 
-private slots:
+private Q_SLOTS:
 
     virtual void generalOptionsListWidgetClicked(QListWidgetItem *);
 
