@@ -29,7 +29,7 @@
 
 // qt includes
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 // 3-14-2003: this code developed from the javawriter with parts of the
@@ -102,7 +102,7 @@ void CppWriter::writeClass(UMLClassifier *c)
     // find an appropriate name for our file
     fileName_ = findFileName(c, QStringLiteral(".h"));
     if (fileName_.isEmpty()) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
@@ -110,7 +110,7 @@ void CppWriter::writeClass(UMLClassifier *c)
 
     if (c->visibility() != Uml::Visibility::Implementation) {
         if (!openFile(fileh, fileName_)) {
-            emit codeGenerated(c, false);
+            Q_EMIT codeGenerated(c, false);
             return;
         }
         // write Header file
@@ -125,9 +125,9 @@ void CppWriter::writeClass(UMLClassifier *c)
         need_impl = false;
     }
     if (need_impl) {
-        fileName_.replace(QRegExp(QStringLiteral(".h$")), QStringLiteral(".cpp"));
+        fileName_.replace(QRegularExpression(QStringLiteral(".h$")), QStringLiteral(".cpp"));
         if (!openFile(filecpp, fileName_)) {
-            emit codeGenerated(c, false);
+            Q_EMIT codeGenerated(c, false);
             return;
         }
         // write Source file
@@ -135,7 +135,7 @@ void CppWriter::writeClass(UMLClassifier *c)
         filecpp.close();
     }
 
-    emit codeGenerated(c, true);
+    Q_EMIT codeGenerated(c, true);
 }
 
 /**
@@ -149,13 +149,13 @@ void CppWriter::writeHeaderFile (UMLClassifier *c, QFile &file)
     // write header blurb
     QString str = getHeadingFile(QStringLiteral(".h"));
     if (!str.isEmpty()) {
-        str.replace(QRegExp(QStringLiteral("%filename%")), fileName_ + QStringLiteral(".h"));
-        str.replace(QRegExp(QStringLiteral("%filepath%")), file.fileName());
+        str.replace(QRegularExpression(QStringLiteral("%filename%")), fileName_ + QStringLiteral(".h"));
+        str.replace(QRegularExpression(QStringLiteral("%filepath%")), file.fileName());
         h << str<< m_endl;
     }
 
     // Write the hash define stuff to prevent multiple parsing/inclusion of header
-    QString hashDefine = className_.toUpper().simplified().replace(QRegExp(QStringLiteral(" ")),  QStringLiteral("_"));
+    QString hashDefine = className_.toUpper().simplified().replace(QRegularExpression(QStringLiteral(" ")),  QStringLiteral("_"));
     writeBlankLine(h);
     h << "#ifndef "<< hashDefine << "_H" << m_endl;
     h << "#define "<< hashDefine << "_H" << m_endl;
@@ -222,8 +222,8 @@ void CppWriter::writeSourceFile(UMLClassifier *c, QFile &file)
     QString str;
     str = getHeadingFile(QStringLiteral(".cpp"));
     if (!str.isEmpty()) {
-        str.replace(QRegExp(QStringLiteral("%filename%")), fileName_ + QStringLiteral(".cpp"));
-        str.replace(QRegExp(QStringLiteral("%filepath%")), file.fileName());
+        str.replace(QRegularExpression(QStringLiteral("%filename%")), fileName_ + QStringLiteral(".cpp"));
+        str.replace(QRegularExpression(QStringLiteral("%filepath%")), file.fileName());
         cpp << str << m_endl;
     }
 
@@ -337,7 +337,7 @@ void CppWriter::writeSourceFile(UMLClassifier *c, QFile &file)
 void CppWriter::writeIncludes(UMLClassifier *c, QTextStream &stream)
 {
     UMLClassifierList superclasses = c->getSuperClasses();
-    foreach (UMLClassifier* classifier, superclasses) {
+    for(UMLClassifier* classifier : superclasses) {
         QString headerName = findFileName(classifier, QStringLiteral(".h"));
         if (!headerName.isEmpty()) {
             stream << "#include \"" << headerName << "\"" << m_endl;
@@ -373,7 +373,7 @@ void CppWriter::writeClassDecl(UMLClassifier *c, QTextStream &cpp)
         writeBlankLine(cpp);
     }
 
-    foreach (UMLClassifier* classifier, c->getSuperClasses()) {
+    for(UMLClassifier* classifier : c->getSuperClasses()) {
         if (classifier->package()!=c->package() && !classifier->package().isEmpty()) {
             cpp << "using " << cleanName(classifier->package()) << "::" << cleanName(classifier->name()) << ";" << m_endl;
         }
@@ -406,7 +406,7 @@ void CppWriter::writeClassDecl(UMLClassifier *c, QTextStream &cpp)
         UMLClassifierListItemList litList = c->getFilteredList(UMLObject::ot_EnumLiteral);
         uint i = 0;
         cpp << "enum " << className_ << " {" << m_endl;
-        foreach (UMLClassifierListItem* lit, litList) {
+        for(UMLClassifierListItem* lit : litList) {
             UMLEnumLiteral *el = static_cast<UMLEnumLiteral *>(lit);
             QString enumLiteral = cleanName(lit->name());
             cpp << indent() << enumLiteral;
@@ -444,7 +444,7 @@ void CppWriter::writeClassDecl(UMLClassifier *c, QTextStream &cpp)
     if (numOfSuperClasses > 0)
         cpp << " : ";
     uint i = 0;
-    foreach (UMLClassifier* superClass, c->getSuperClasses()) {
+    for(UMLClassifier* superClass : c->getSuperClasses()) {
         i++;
         if (superClass->isAbstract() || superClass->isInterface())
             cpp << "virtual ";
@@ -540,7 +540,7 @@ void CppWriter::writeAttributeDecls (UMLClassifier *c, Uml::Visibility::Enum vis
         // write attrib declarations now
         // bool isFirstAttrib = true;
         QString documentation;
-        foreach (UMLAttribute* at, list) {
+        for(UMLAttribute* at : list) {
 
             //                  bool noPriorDocExists = documentation.isEmpty();
             documentation = at->doc();
@@ -615,7 +615,7 @@ void CppWriter::writeAttributeMethods(UMLAttributeList attribs,
     if (attribs.count() == 0)
         return;
 
-    foreach (UMLAttribute* at, attribs) {
+    for(UMLAttribute* at : attribs) {
         QString varName = getAttributeVariableName(at);
         QString methodBaseName = getAttributeMethodBaseName(cleanName(at->name()));
 
@@ -694,7 +694,7 @@ void CppWriter::writeAssociationDecls(UMLAssociationList associations, Uml::Visi
     if (forceSections() || !associations.isEmpty())
     {
         bool printRoleA = false, printRoleB = false;
-        foreach (UMLAssociation *a, associations)
+        for(UMLAssociation *a : associations)
         {
             // it may seem counter intuitive, but you want to insert the role of the
             // *other* class into *this* class.
@@ -752,14 +752,14 @@ void CppWriter::writeAssociationRoleDecl(QString fieldClassName, QString roleNam
     // declare the association based on whether it is this a single variable
     // or a List (Vector). One day this will be done correctly with special
     // multiplicity object that we don't have to figure out what it means via regex.
-    if (multi.isEmpty() || multi.contains(QRegExp(QStringLiteral("^[01]$"))))
+    if (multi.isEmpty() || multi.contains(QRegularExpression(QStringLiteral("^[01]$"))))
     {
         QString fieldVarName = QStringLiteral("m_") + roleName.toLower();
 
         // record this for later consideration of initialization IF the
         // multi value requires 1 of these objects
         if (ObjectFieldVariables.indexOf(fieldVarName) == -1 &&
-                multi.contains(QRegExp(QStringLiteral("^1$"))))
+                multi.contains(QRegularExpression(QStringLiteral("^1$"))))
         {
             // ugh. UGLY. Storing variable name and its class in pairs.
             ObjectFieldVariables.append(fieldVarName);
@@ -795,7 +795,7 @@ void CppWriter::writeAssociationMethods (UMLAssociationList associations,
 {
     if (forceSections() || !associations.isEmpty())
     {
-        foreach (UMLAssociation *a, associations)
+        for (UMLAssociation *a : associations)
         {
 
             // insert the methods to access the role of the other
@@ -846,7 +846,7 @@ void CppWriter::writeAssociationRoleMethod (const QString &fieldClassName,
         const QString &description, Uml::Changeability::Enum change,
         QTextStream &stream)
 {
-    if (multi.isEmpty() || multi.contains(QRegExp(QStringLiteral("^[01]$"))))
+    if (multi.isEmpty() || multi.contains(QRegularExpression(QStringLiteral("^[01]$"))))
     {
         QString fieldVarName = QStringLiteral("m_") + roleName.toLower();
         writeSingleAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
@@ -885,9 +885,9 @@ void CppWriter::writeVectorAttributeAccessorMethods (
         stream << "add" << fldName << " (" << className << " add_object)";
         if (writeMethodBody) {
             QString method = VECTOR_METHOD_APPEND;
-            method.replace(QRegExp(QStringLiteral("%VARNAME%")), fieldVarName);
-            method.replace(QRegExp(QStringLiteral("%VECTORTYPENAME%")), policyExt()->getVectorClassName());
-            method.replace(QRegExp(QStringLiteral("%ITEMCLASS%")), className);
+            method.replace(QRegularExpression(QStringLiteral("%VARNAME%")), fieldVarName);
+            method.replace(QRegularExpression(QStringLiteral("%VECTORTYPENAME%")), policyExt()->getVectorClassName());
+            method.replace(QRegularExpression(QStringLiteral("%ITEMCLASS%")), className);
             stream << indnt << " {" << m_endl;
             m_indentLevel++;
             printTextAsSeparateLinesWithIndent(method, indent(), stream);
@@ -908,9 +908,9 @@ void CppWriter::writeVectorAttributeAccessorMethods (
         stream << "remove" << fldName << " (" << className << " remove_object)";
         if (writeMethodBody) {
             QString method = VECTOR_METHOD_REMOVE;
-            method.replace(QRegExp(QStringLiteral("%VARNAME%")), fieldVarName);
-            method.replace(QRegExp(QStringLiteral("%VECTORTYPENAME%")), policyExt()->getVectorClassName());
-            method.replace(QRegExp(QStringLiteral("%ITEMCLASS%")), className);
+            method.replace(QRegularExpression(QStringLiteral("%VARNAME%")), fieldVarName);
+            method.replace(QRegularExpression(QStringLiteral("%VECTORTYPENAME%")), policyExt()->getVectorClassName());
+            method.replace(QRegularExpression(QStringLiteral("%ITEMCLASS%")), className);
             stream << indnt << " {" << m_endl;
             m_indentLevel++;
             printTextAsSeparateLinesWithIndent(method, indent(), stream);
@@ -1080,7 +1080,7 @@ void CppWriter::writeInitAttributeMethod(UMLClassifier * c, QTextStream &stream)
     m_indentLevel++;
     // first, initiation of fields derived from attributes
     UMLAttributeList atl = c->getAttributeList();
-    foreach (UMLAttribute* at, atl) {
+    for (UMLAttribute* at : atl) {
         if (!at->getInitialValue().isEmpty()) {
             QString varName = getAttributeVariableName(at);
             stream << indent() << varName << " = " << at->getInitialValue() << ";" << m_endl;
@@ -1092,8 +1092,8 @@ void CppWriter::writeInitAttributeMethod(UMLClassifier * c, QTextStream &stream)
         for (it = VectorFieldVariables.begin(); it != VectorFieldVariables.end(); ++it) {
             QString fieldVarName = *it;
             QString method = VECTOR_METHOD_INIT;
-            method.replace(QRegExp(QStringLiteral("%VARNAME%")), fieldVarName);
-            method.replace(QRegExp(QStringLiteral("%VECTORTYPENAME%")), policyExt()->getVectorClassName());
+            method.replace(QRegularExpression(QStringLiteral("%VARNAME%")), fieldVarName);
+            method.replace(QRegularExpression(QStringLiteral("%VECTORTYPENAME%")), policyExt()->getVectorClassName());
             stream << indent() << method << m_endl;
         }
     }
@@ -1105,8 +1105,8 @@ void CppWriter::writeInitAttributeMethod(UMLClassifier * c, QTextStream &stream)
             it++;
             QString fieldClassName = *it;
             QString method = OBJECT_METHOD_INIT;
-            method.replace(QRegExp(QStringLiteral("%VARNAME%")), fieldVarName);
-            method.replace(QRegExp(QStringLiteral("%ITEMCLASS%")), fieldClassName);
+            method.replace(QRegularExpression(QStringLiteral("%VARNAME%")), fieldVarName);
+            method.replace(QRegularExpression(QStringLiteral("%ITEMCLASS%")), fieldClassName);
             stream << indent() << method << m_endl;
         }
     }
@@ -1160,7 +1160,7 @@ void CppWriter::writeConstructorMethods(UMLClassifier * c, QTextStream &stream)
  */
 void CppWriter::writeDataTypes(UMLClassifier *c, Uml::Visibility::Enum permitScope, QTextStream &stream)
 {
-    foreach (UMLObject* o, c->containedObjects()) {
+    for (UMLObject* o : c->containedObjects()) {
         uIgnoreZeroPointer(o);
         if (o->visibility() != permitScope)
             continue;
@@ -1201,7 +1201,7 @@ void CppWriter::writeOperations(UMLClassifier *c, bool isHeaderMethod,
 
     //sort operations by scope first and see if there are abstract methods
     UMLOperationList inputlist = c->getOpList();
-    foreach (UMLOperation* op, inputlist) {
+    for (UMLOperation* op : inputlist) {
         if (op->visibility() == permitScope) {
             oplist.append(op);
         }
@@ -1232,7 +1232,7 @@ void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool
         UMLApp::app()->commonPolicy()->getAutoGenerateConstructors();
 
     // generate method decl for each operation given
-    foreach (UMLOperation* op, oplist) {
+    for (UMLOperation* op : oplist) {
         QString doc;  // buffer for documentation
         QString methodReturnType;
         UMLAttributeList atl = op->getParmList();  // method parameters
@@ -1290,7 +1290,7 @@ void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool
                 str += QStringLiteral(", ");
             doc += policyExt()->getDocToolTag() + QStringLiteral("param  ") + atName + QLatin1Char(' ') + at->doc() + m_endl;
         }
-        doc = doc.remove(doc.size() - 1, 1);  // remove last endl of comment
+        doc = doc.remove(doc.size() - 1, 1);  // remove last '\n' of comment
         str += QLatin1Char(')');
 
         if (op->getConst())
@@ -1335,8 +1335,8 @@ void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool
  */
 void CppWriter::printAssociationIncludeDecl(UMLAssociationList list, Uml::ID::Type myId, QTextStream &stream)
 {
-    foreach (UMLAssociation *a, list) {
-        UMLClassifier *current = 0;
+    for (UMLAssociation *a : list) {
+        UMLClassifier *current = nullptr;
         bool isFirstClass = true;
 
         // only use OTHER classes (e.g. we don't need to write includes for ourselves!!
@@ -1428,7 +1428,7 @@ QString CppWriter::getAttributeMethodBaseName(const QString &fieldName)
 {
     QString fldName = fieldName;
     if (policyExt()->getRemovePrefixFromAccessorMethods())
-        fldName.replace(QRegExp(QStringLiteral("^[a-zA-Z]_")), QStringLiteral(""));
+        fldName.replace(QRegularExpression(QStringLiteral("^[a-zA-Z]_")), QStringLiteral(""));
     return fldName;
 }
 
