@@ -22,7 +22,7 @@
 
 // qt includes
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 /**
@@ -79,7 +79,7 @@ void DWriter::writeModuleImports(UMLClassifier *c, QTextStream &d)
     //only import classes in a different package as this class
     UMLPackageList imports;
     findObjectsRelated(c, imports);
-    foreach (UMLPackage* con, imports) {
+    for(UMLPackage* con : imports) {
         if (con->isUMLDatatype())
             continue;
         QString pkg = con->package();
@@ -109,14 +109,14 @@ void DWriter::writeClass(UMLClassifier *c)
     //find an appropriate name for our file
     fileName = findFileName(c, QStringLiteral(".d"));
     if (fileName.isEmpty()) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
     // check that we may open that file for writing
     QFile file;
     if (!openFile(file, fileName)) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
@@ -127,8 +127,8 @@ void DWriter::writeClass(UMLClassifier *c)
     QString str;
     str = getHeadingFile(QStringLiteral(".d"));
     if (!str.isEmpty()) {
-        str.replace(QRegExp(QStringLiteral("%filename%")), fileName);
-        str.replace(QRegExp(QStringLiteral("%filepath%")), file.fileName());
+        str.replace(QRegularExpression(QStringLiteral("%filename%")), fileName);
+        str.replace(QRegularExpression(QStringLiteral("%filepath%")), file.fileName());
         d<<str<<m_endl;
     }
 
@@ -155,7 +155,7 @@ void DWriter::writeClass(UMLClassifier *c)
 
     if (!isInterface) {
         UMLAttributeList atl = c->getAttributeList();
-        foreach (UMLAttribute* at, atl) {
+        for(UMLAttribute* at : atl) {
             switch(at->visibility())
             {
                 case Uml::Visibility::Public:
@@ -274,7 +274,7 @@ void DWriter::writeClass(UMLClassifier *c)
     d << "}" << m_endl; // end class
 
     file.close();
-    emit codeGenerated(c, true);
+    Q_EMIT codeGenerated(c, true);
 }
 
 void DWriter::writeClassDecl(UMLClassifier *c, QTextStream &d)
@@ -350,7 +350,7 @@ void DWriter::writeClassDecl(UMLClassifier *c, QTextStream &d)
         d << " : ";
 
         // (f) base classes
-        foreach (UMLClassifier* classifier, superclasses) {
+        for(UMLClassifier* classifier : superclasses) {
             d << cleanName(classifier->name());
 
             count--;
@@ -359,7 +359,7 @@ void DWriter::writeClassDecl(UMLClassifier *c, QTextStream &d)
         }
 
         // (g) interfaces
-        foreach (UMLClassifier* classifier, superinterfaces) {
+        for(UMLClassifier* classifier : superinterfaces) {
             d << cleanName(classifier->name());
 
             count--;
@@ -380,7 +380,7 @@ void DWriter::writeAttributeDecl(Uml::Visibility::Enum visibility, UMLAttributeL
 
     writeProtectionMod(visibility, d);
 
-    foreach (UMLAttribute* at, atlist) {
+    for(UMLAttribute* at : atlist) {
         // documentation
         if (!at->doc().isEmpty()) {
             writeComment(at->doc(), m_indentation, d, true);
@@ -425,7 +425,7 @@ void DWriter::writeAttributeMethods(UMLAttributeList &atpub, Uml::Visibility::En
 
     writeProtectionMod(visibility, d);
 
-    foreach (UMLAttribute* at, atpub) {
+    for(UMLAttribute* at : atpub) {
         QString fieldName = cleanName(at->name());
         writeSingleAttributeAccessorMethods(
             at->getTypeName(), QStringLiteral("m_") + fieldName, fieldName, at->doc(),
@@ -488,7 +488,7 @@ void DWriter::writeAssociationDecls(UMLAssociationList associations, Uml::ID::Ty
     if (forceSections() || !associations.isEmpty())
     {
         bool printRoleA = false, printRoleB = false;
-        foreach (UMLAssociation *a, associations) {
+        for(UMLAssociation *a : associations) {
             // it may seem counter intuitive, but you want to insert the role of the
             // *other* class into *this* class.
             if (a->getObjectId(Uml::RoleType::A) == id)
@@ -535,7 +535,7 @@ void DWriter::writeAssociationRoleDecl(QString fieldClassName,
     // declare the association based on whether it is this a single variable
     // or a List (Vector). One day this will be done correctly with special
     // multiplicity object that we don't have to figure out what it means via regex.
-    if (multi.isEmpty() || multi.contains(QRegExp(QStringLiteral("^[01]$")))) {
+    if (multi.isEmpty() || multi.contains(QRegularExpression(QStringLiteral("^[01]$")))) {
         d << m_indentation << fieldClassName << " ";
 
         if (hasAccessors) d << "m_";
@@ -559,7 +559,7 @@ void DWriter::writeAssociationRoleDecl(QString fieldClassName,
 void DWriter::writeAssociationMethods (UMLAssociationList associations, UMLClassifier *thisClass, QTextStream &d)
 {
     if (forceSections() || !associations.isEmpty()) {
-        foreach (UMLAssociation *a, associations) {
+        for(UMLAssociation *a : associations) {
             // insert the methods to access the role of the other
             // class in the code of this one
             if (a->getObjectId(Uml::RoleType::A) == thisClass->id()) {
@@ -594,7 +594,7 @@ void DWriter::writeAssociationRoleMethod (QString fieldClassName, QString roleNa
         QString description, Uml::Visibility::Enum visib, Uml::Changeability::Enum change,
         QTextStream &d)
 {
-    if (multi.isEmpty() || multi.contains(QRegExp(QStringLiteral("^[01]$")))) {
+    if (multi.isEmpty() || multi.contains(QRegularExpression(QStringLiteral("^[01]$")))) {
         QString fieldVarName = QStringLiteral("m_") + deCapitaliseFirstLetter(roleName);
 
         writeSingleAttributeAccessorMethods(
@@ -760,7 +760,7 @@ QStringList DWriter::defaultDatatypes() const
 
 bool DWriter::compareDMethod(UMLOperation *op1, UMLOperation *op2)
 {
-    if (op1 == 0 || op2 == 0)
+    if (op1 == nullptr || op2 == nullptr)
         return false;
     if (op1 == op2)
         return true;
@@ -782,7 +782,7 @@ bool DWriter::compareDMethod(UMLOperation *op1, UMLOperation *op2)
 
 bool DWriter::dMethodInList(UMLOperation *umlOp, UMLOperationList &opl)
 {
-    foreach (UMLOperation* op, opl) {
+    for(UMLOperation* op : opl) {
         if (DWriter::compareDMethod(op, umlOp)) {
             return true;
         }
@@ -794,10 +794,10 @@ void DWriter::getSuperImplementedOperations(UMLClassifier *c, UMLOperationList &
 {
     UMLClassifierList superClasses = c->findSuperClassConcepts();
 
-    foreach (UMLClassifier* classifier, superClasses) {
+    for(UMLClassifier* classifier : superClasses) {
         getSuperImplementedOperations(classifier, yetImplementedOpList, toBeImplementedOpList, (classifier->isInterface() && noClassInPath));
         UMLOperationList opl = classifier->getOpList();
-        foreach (UMLOperation* op, opl) {
+        for(UMLOperation* op : opl) {
             if (classifier->isInterface() && noClassInPath) {
                 if (!DWriter::dMethodInList(op, toBeImplementedOpList))
                     toBeImplementedOpList.append(op);
@@ -817,7 +817,7 @@ void DWriter::getInterfacesOperationsToBeImplemented(UMLClassifier *c, UMLOperat
     UMLOperationList toBeImplementedOpList;
 
     getSuperImplementedOperations(c, yetImplementedOpList, toBeImplementedOpList);
-    foreach (UMLOperation* op, toBeImplementedOpList) {
+    for(UMLOperation* op : toBeImplementedOpList) {
         if (! DWriter::dMethodInList(op, yetImplementedOpList) && ! DWriter::dMethodInList(op, opList))
             opList.append(op);
     }
@@ -833,7 +833,7 @@ void DWriter::writeOperations(UMLClassifier *c, QTextStream &d)
     if (! c->isInterface()) {
         getInterfacesOperationsToBeImplemented(c, opl);
     }
-    foreach (UMLOperation* op, opl) {
+    for(UMLOperation* op : opl) {
         switch(op->visibility()) {
           case Uml::Visibility::Public:
             oppub.append(op);
@@ -884,7 +884,7 @@ void DWriter::writeOperations(UMLOperationList &oplist, QTextStream &d)
     QString str;
 
     // generate method decl for each operation given
-    foreach (UMLOperation* op, oplist) {
+    for(UMLOperation* op : oplist) {
         QString doc;
         // write documentation
 
@@ -914,7 +914,7 @@ void DWriter::writeOperations(UMLOperationList &oplist, QTextStream &d)
                    + ((j < i-1) ? QStringLiteral(", ") : QString());
             doc += QStringLiteral("@param ") + atName + QLatin1Char(' ') + at->doc() + m_endl;
         }
-        doc = doc.remove(doc.size() - 1, 1);  // remove last endl of comment
+        doc = doc.remove(doc.size() - 1, 1);  // remove last '\n' of comment
         str += QLatin1Char(')');
 
         // method only gets a body IF it is not abstract
