@@ -24,7 +24,7 @@
 #include "uml.h"
 
 // qt includes
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QXmlStreamWriter>
 
 /**
@@ -77,7 +77,7 @@ void RubyCodeAccessorMethod::updateContent()
     RubyCodeClassField * rubyfield = dynamic_cast<RubyCodeClassField*>(parentField);
 
     // Check for dynamic casting failure!
-    if (rubyfield == 0)
+    if (rubyfield == nullptr)
     {
         logError0("rubyfield: invalid dynamic cast");
         return;
@@ -94,21 +94,21 @@ void RubyCodeAccessorMethod::updateContent()
             QString fieldType = rubyfield->getTypeName();
             QString indent = getIndentation();
             if (maxOccurs > 0)
-                text += QLatin1String("if ") + fieldName + QLatin1String(".size() < ")+ QString::number(maxOccurs) + QLatin1Char(' ') + endLine + indent;
-            text += fieldName + QLatin1String(".push(value)");
+                text += QStringLiteral("if ") + fieldName + QStringLiteral(".size() < ")+ QString::number(maxOccurs) + QLatin1Char(' ') + endLine + indent;
+            text += fieldName + QStringLiteral(".push(value)");
             if (maxOccurs > 0)
             {
-                text += endLine + QLatin1String("else") + endLine;
-                text += indent + QLatin1String("puts(\"ERROR: Cannot add") + fieldType + QLatin1String(" to ") + fieldName
-                     + QLatin1String(", minimum number of items reached.\")") + endLine + QLatin1String("end") + endLine;
+                text += endLine + QStringLiteral("else") + endLine;
+                text += indent + QStringLiteral("puts(\"ERROR: Cannot add") + fieldType + QStringLiteral(" to ") + fieldName
+                     + QStringLiteral(", minimum number of items reached.\")") + endLine + QStringLiteral("end") + endLine;
             }
             break;
         }
     case CodeAccessorMethod::GET:
-//        text = QLatin1String("return ") + fieldName;
+//        text = QStringLiteral("return ") + fieldName;
         break;
     case CodeAccessorMethod::LIST:
-        text = QLatin1String("return ") + fieldName;
+        text = QStringLiteral("return ") + fieldName;
         break;
     case CodeAccessorMethod::REMOVE:
         {
@@ -117,17 +117,17 @@ void RubyCodeAccessorMethod::updateContent()
             QString indent = getIndentation();
 
             if (minOccurs > 0)
-                text += QLatin1String("if ") + fieldName + QLatin1String(".size() >= ") + QString::number(minOccurs) + endLine + indent;
-            text += fieldName + QLatin1String(".delete(value)");
+                text += QStringLiteral("if ") + fieldName + QStringLiteral(".size() >= ") + QString::number(minOccurs) + endLine + indent;
+            text += fieldName + QStringLiteral(".delete(value)");
             if (minOccurs > 0)
             {
-                text += endLine + QLatin1String("else") + endLine;
-                text += indent + QLatin1String("puts(\"ERROR: Cant remove") + fieldType + QLatin1String(" from ") + fieldName + QLatin1String(", minimum number of items reached.\")") + endLine + QLatin1String("end") + endLine;
+                text += endLine + QStringLiteral("else") + endLine;
+                text += indent + QStringLiteral("puts(\"ERROR: Cant remove") + fieldType + QStringLiteral(" from ") + fieldName + QStringLiteral(", minimum number of items reached.\")") + endLine + QStringLiteral("end") + endLine;
             }
             break;
         }
     case CodeAccessorMethod::SET:
-//        text = fieldName + QLatin1String(" = value");
+//        text = fieldName + QStringLiteral(" = value");
         break;
     default:
         // do nothing
@@ -142,7 +142,7 @@ void RubyCodeAccessorMethod::updateMethodDeclaration()
     RubyCodeClassField * rubyfield = dynamic_cast<RubyCodeClassField*>(getParentClassField());
 
     // Check for dynamic casting failure!
-    if (rubyfield == 0)
+    if (rubyfield == nullptr)
     {
         logError0("rubyfield: invalid dynamic cast");
         return;
@@ -160,9 +160,9 @@ void RubyCodeAccessorMethod::updateMethodDeclaration()
     QString endLine = p->getNewLineEndingChars();
 
     QString description = getParentObject()->doc();
-    description.remove(QRegExp(QLatin1String("m_[npb](?=[A-Z])")));
-    description.remove(QLatin1String("m_"));
-    description.replace(QRegExp(QLatin1String("[\\n\\r]+[\\t ]*")), endLine);
+    description.remove(QRegularExpression(QStringLiteral("m_[npb](?=[A-Z])")));
+    description.remove(QStringLiteral("m_"));
+    description.replace(QRegularExpression(QStringLiteral("[\\n\\r]+[\\t ]*")), endLine);
 
     // set scope of this accessor appropriately..if its an attribute,
     // we need to be more sophisticated
@@ -187,36 +187,36 @@ void RubyCodeAccessorMethod::updateMethodDeclaration()
 
     switch(getType()) {
     case CodeAccessorMethod::ADD:
-        methodName = QLatin1String("add") + Codegen_Utils::capitalizeFirstLetter(fieldType);
+        methodName = QStringLiteral("add") + Codegen_Utils::capitalizeFirstLetter(fieldType);
         methodReturnType = QString();
-        methodParams = objectType + QLatin1String(" value ");
-        headerText = QLatin1String("Add an object of type ") + objectType + QLatin1String(" to the Array ") + fieldName + endLine + description + endLine + QLatin1String("@return nil");
-        setStartMethodText(QLatin1String("def ")+ methodName + QLatin1Char('(') + methodParams + QLatin1Char(')'));
-        setEndMethodText(QLatin1String("end"));
+        methodParams = objectType + QStringLiteral(" value ");
+        headerText = QStringLiteral("Add an object of type ") + objectType + QStringLiteral(" to the Array ") + fieldName + endLine + description + endLine + QStringLiteral("@return nil");
+        setStartMethodText(QStringLiteral("def ")+ methodName + QLatin1Char('(') + methodParams + QLatin1Char(')'));
+        setEndMethodText(QStringLiteral("end"));
         break;
     case CodeAccessorMethod::GET:
-        headerText = QLatin1String("Get the value of ") + fieldName + endLine + description;
-        setStartMethodText(QString(QLatin1String("attr_reader :")) + fieldName);
+        headerText = QStringLiteral("Get the value of ") + fieldName + endLine + description;
+        setStartMethodText(QString(QStringLiteral("attr_reader :")) + fieldName);
         setEndMethodText(QString());
         break;
     case CodeAccessorMethod::LIST:
-        methodName = QLatin1String("get") + Codegen_Utils::capitalizeFirstLetter(fieldType) + QLatin1String("List");
+        methodName = QStringLiteral("get") + Codegen_Utils::capitalizeFirstLetter(fieldType) + QStringLiteral("List");
         methodReturnType = QString();
-        headerText = QLatin1String("Get the list of ") + fieldName + endLine + description + endLine + QLatin1String("_returns_ List of ") + fieldName;
-        setStartMethodText(QLatin1String("def ")+ methodName + QLatin1Char('(') + methodParams + QLatin1Char(')'));
-        setEndMethodText(QLatin1String("end"));
+        headerText = QStringLiteral("Get the list of ") + fieldName + endLine + description + endLine + QStringLiteral("_returns_ List of ") + fieldName;
+        setStartMethodText(QStringLiteral("def ")+ methodName + QLatin1Char('(') + methodParams + QLatin1Char(')'));
+        setEndMethodText(QStringLiteral("end"));
         break;
     case CodeAccessorMethod::REMOVE:
-        methodName = QLatin1String("remove") + Codegen_Utils::capitalizeFirstLetter(fieldType);
+        methodName = QStringLiteral("remove") + Codegen_Utils::capitalizeFirstLetter(fieldType);
         methodReturnType = QString();
-        methodParams = objectType + QLatin1String(" value ");
-        headerText = QLatin1String("Remove an object of type ") + objectType + QLatin1String(" from the List ") + fieldName + endLine + description;
-        setStartMethodText(QLatin1String("def ") + methodName + QLatin1Char('(') + methodParams + QLatin1Char(')'));
-        setEndMethodText(QLatin1String("end"));
+        methodParams = objectType + QStringLiteral(" value ");
+        headerText = QStringLiteral("Remove an object of type ") + objectType + QStringLiteral(" from the List ") + fieldName + endLine + description;
+        setStartMethodText(QStringLiteral("def ") + methodName + QLatin1Char('(') + methodParams + QLatin1Char(')'));
+        setEndMethodText(QStringLiteral("end"));
         break;
     case CodeAccessorMethod::SET:
-        headerText = QLatin1String("Set the value of ") + fieldName + endLine + description;
-        setStartMethodText(QString(QLatin1String("attr_writer :")) + fieldName);
+        headerText = QStringLiteral("Set the value of ") + fieldName + endLine + description;
+        setStartMethodText(QString(QStringLiteral("attr_writer :")) + fieldName);
         setEndMethodText(QString());
         break;
     default:
