@@ -20,7 +20,7 @@
 #include <KMessageBox>
 
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 RubyWriter::RubyWriter()
@@ -49,13 +49,13 @@ void RubyWriter::writeClass(UMLClassifier *c)
     //find an appropriate name for our file
     fileName_ = findFileName(c, QStringLiteral(".rb"));
     if (fileName_.isEmpty()) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
     QFile fileh;
     if (!openFile(fileh, fileName_)) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
     QTextStream h(&fileh);
@@ -71,14 +71,14 @@ void RubyWriter::writeClass(UMLClassifier *c)
 
     str = getHeadingFile(QStringLiteral(".rb"));
     if (!str.isEmpty()) {
-        str.replace(QRegExp(QStringLiteral("%filename%")), fileName_);
-        str.replace(QRegExp(QStringLiteral("%filepath%")), fileh.fileName());
+        str.replace(QRegularExpression(QStringLiteral("%filename%")), fileName_);
+        str.replace(QRegularExpression(QStringLiteral("%filepath%")), fileh.fileName());
         h << str << m_endl;
     }
 
     if (forceDoc() || !c->doc().isEmpty()) {
         QString docStr = c->doc();
-        docStr.replace(QRegExp(QStringLiteral("\\n")), QStringLiteral("\n# "));
+        docStr.replace(QRegularExpression(QStringLiteral("\\n")), QStringLiteral("\n# "));
         docStr.remove(QStringLiteral("@ref "));
         docStr.replace(QStringLiteral("@see"), QStringLiteral("_See_"));
         docStr.replace(QStringLiteral("@short"), QStringLiteral("_Summary_"));
@@ -89,12 +89,11 @@ void RubyWriter::writeClass(UMLClassifier *c)
     }
 
     // write inheritances out
-    UMLClassifier *classifier;
 
     h <<  "class " << cppToRubyType(className_) << (superclasses.count() > 0 ? QStringLiteral(" < ") : QString());
 
     int i = 0;
-    foreach (classifier, superclasses) {
+    for(UMLClassifier *classifier: superclasses) {
         if (i == 0) {
             h << cppToRubyType(classifier->name()) << m_endl;
         } else {
@@ -128,7 +127,7 @@ void RubyWriter::writeClass(UMLClassifier *c)
 
     //close files and notfiy we are done
     fileh.close();
-    emit codeGenerated(c, true);
+    Q_EMIT codeGenerated(c, true);
 }
 
 /**
@@ -140,15 +139,15 @@ QString RubyWriter::cppToRubyType(const QString &typeStr)
 {
     QString type = cleanName(typeStr);
     type.remove(QStringLiteral("const "));
-    type.remove(QRegExp(QStringLiteral("[*&\\s]")));
-    type.replace(QRegExp(QStringLiteral("[<>]")), QStringLiteral("_"));
+    type.remove(QRegularExpression(QStringLiteral("[*&\\s]")));
+    type.replace(QRegularExpression(QStringLiteral("[<>]")), QStringLiteral("_"));
     type.replace(QStringLiteral("QStringList"), QStringLiteral("Array"));
     type.replace(QStringLiteral("QString"), QStringLiteral("String"));
     type.replace(QStringLiteral("bool"), QStringLiteral("true|false"));
-    type.replace(QRegExp(QStringLiteral("^(uint|int|ushort|short|ulong|long)$")), QStringLiteral("Integer"));
-    type.replace(QRegExp(QStringLiteral("^(float|double)$")), QStringLiteral("Float"));
-    type.replace(QRegExp(QStringLiteral("^Q(?=[A-Z])")), QStringLiteral("Qt::"));
-    type.replace(QRegExp(QStringLiteral("^K(?!(DE|Parts|IO)")), QStringLiteral("KDE::"));
+    type.replace(QRegularExpression(QStringLiteral("^(uint|int|ushort|short|ulong|long)$")), QStringLiteral("Integer"));
+    type.replace(QRegularExpression(QStringLiteral("^(float|double)$")), QStringLiteral("Float"));
+    type.replace(QRegularExpression(QStringLiteral("^Q(?=[A-Z])")), QStringLiteral("Qt::"));
+    type.replace(QRegularExpression(QStringLiteral("^K(?!(DE|Parts|IO)")), QStringLiteral("KDE::"));
 
     return type;
 }
@@ -161,8 +160,8 @@ QString RubyWriter::cppToRubyType(const QString &typeStr)
 QString RubyWriter::cppToRubyName(const QString &nameStr)
 {
     QString name = cleanName(nameStr);
-    name.remove(QRegExp(QStringLiteral("^m_")));
-    name.remove(QRegExp(QStringLiteral("^[pbn](?=[A-Z])")));
+    name.remove(QRegularExpression(QStringLiteral("^m_")));
+    name.remove(QRegularExpression(QStringLiteral("^[pbn](?=[A-Z])")));
     name = name.mid(0, 1).toLower() + name.mid(1);
     return name;
 }
@@ -179,7 +178,7 @@ void RubyWriter::writeOperations(UMLClassifier *c, QTextStream &h)
 
     //sort operations by scope first and see if there are abstract methods
     UMLOperationList opl(c->getOpList());
-    foreach (UMLOperation *op, opl) {
+    for(UMLOperation *op : opl) {
         switch(op->visibility()) {
         case Uml::Visibility::Public:
             oppub.append(op);
@@ -238,7 +237,7 @@ void RubyWriter::writeOperations(const QString &classname, const UMLOperationLis
         break;
     }
 
-    foreach (const UMLOperation* op, opList) {
+    for(const UMLOperation *op : opList) {
         QString methodName = cleanName(op->name());
         QStringList commentedParams;
 
@@ -271,26 +270,27 @@ void RubyWriter::writeOperations(const QString &classname, const UMLOperationLis
             h << m_indentation << "#" << m_endl;
             QString docStr = op->doc();
 
-            docStr.replace(QRegExp(QStringLiteral("[\\n\\r]+ *")), m_endl);
-            docStr.replace(QRegExp(QStringLiteral("[\\n\\r]+\\t*")), m_endl);
+            docStr.replace(QRegularExpression(QStringLiteral("[\\n\\r]+ *")), m_endl);
+            docStr.replace(QRegularExpression(QStringLiteral("[\\n\\r]+\\t*")), m_endl);
 
             docStr.replace(QStringLiteral(" m_"), QStringLiteral(" "));
-            docStr.replace(QRegExp(QStringLiteral("\\s[npb](?=[A-Z])")), QStringLiteral(" "));
-            QRegExp re_params(QStringLiteral("@param (\\w)(\\w*)"));
-            int pos = re_params.indexIn(docStr);
+            docStr.replace(QRegularExpression(QStringLiteral("\\s[npb](?=[A-Z])")), QStringLiteral(" "));
+            QRegularExpression re_params(QStringLiteral("@param (\\w)(\\w*)"));
+            QRegularExpressionMatch re_mat = re_params.match(docStr);
+            int pos = docStr.indexOf(re_params);
             while (pos != -1) {
-                docStr.replace(re_params.cap(0),
-                                QString(QStringLiteral("@param _")) + re_params.cap(1).toLower() + re_params.cap(2) + QLatin1Char('_'));
-                commentedParams.append(re_params.cap(1).toLower() + re_params.cap(2));
+                docStr.replace(re_mat.captured(0),
+                                QString(QStringLiteral("@param _")) + re_mat.captured(1).toLower() + re_mat.captured(2) + QLatin1Char('_'));
+                commentedParams.append(re_mat.captured(1).toLower() + re_mat.captured(2));
 
-                pos += re_params.matchedLength() + 3;
-                pos = re_params.indexIn(docStr, pos);
+                pos += re_mat.capturedLength() + 3;
+                pos = docStr.indexOf(docStr, pos);
             }
 
             docStr.replace(QLatin1Char('\n'), QString(QStringLiteral("\n")) + m_indentation + QStringLiteral("# "));
 
             // Write parameter documentation
-            foreach (UMLAttribute* at, atl) {
+            for(UMLAttribute* at : atl) {
                 // Only write an individual @param entry if one hasn't been found already
                 // in the main doc comment
                 if (commentedParams.contains(cppToRubyName(at->name())) == 0) {
@@ -298,7 +298,7 @@ void RubyWriter::writeOperations(const QString &classname, const UMLOperationLis
                     if (at->doc().isEmpty()) {
                         docStr += (QLatin1Char(' ') + cppToRubyType(at->getTypeName()));
                     } else {
-                        docStr += (QLatin1Char(' ') + at->doc().replace(QRegExp(QStringLiteral("[\\n\\r]+[\\t ]*")), m_endl + QStringLiteral("   ")));
+                        docStr += (QLatin1Char(' ') + at->doc().replace(QRegularExpression(QStringLiteral("[\\n\\r]+[\\t ]*")), m_endl + QStringLiteral("   ")));
                     }
                 }
             }
@@ -312,13 +312,14 @@ void RubyWriter::writeOperations(const QString &classname, const UMLOperationLis
             // item starting with '# *', then indent the text with
             // three spaces, '#   ', to line up with the list item.
             pos = docStr.indexOf(QStringLiteral("# *"));
-            QRegExp re_linestart(QStringLiteral("# (?!\\*)"));
-            pos = re_linestart.indexIn(docStr, pos);
+            QRegularExpression re_linestart(QStringLiteral("# (?!\\*)"));
+            QRegularExpressionMatch re_ls_mat = re_linestart.match(docStr);
+            pos = docStr.indexOf(re_linestart, pos);
             while (pos > 0) {
                 docStr.insert(pos + 1, QStringLiteral("  "));
 
-                pos += re_linestart.matchedLength() + 2;
-                pos = re_linestart.indexIn(docStr, pos);
+                pos += re_ls_mat.capturedLength() + 2;
+                pos = docStr.indexOf(re_linestart, pos);
             }
 
             h << m_indentation << "# " <<  docStr << m_endl;
@@ -332,7 +333,7 @@ void RubyWriter::writeOperations(const QString &classname, const UMLOperationLis
         h << m_indentation << "def " << methodName << "(";
 
         int j=0;
-        foreach (UMLAttribute* at, atl) {
+        for(UMLAttribute *at : atl) {
             QString nameStr = cppToRubyName(at->name());
             if (j > 0) {
                 h << ", " << nameStr;
@@ -374,8 +375,7 @@ void RubyWriter::writeAttributeMethods(UMLAttributeList attribs,
     if (attribs.count() == 0 || visibility == Uml::Visibility::Private)
         return;
 
-    UMLAttribute *at;
-    foreach (at,  attribs)
+    for(UMLAttribute *at:  attribs)
     {
         QString varName = cppToRubyName(cleanName(at->name()));
 
@@ -397,7 +397,7 @@ void RubyWriter::writeSingleAttributeAccessorMethods(
         QTextStream &h)
 {
     QString description = descr;
-    description.remove(QRegExp(QStringLiteral("m_[npb](?=[A-Z])")));
+    description.remove(QRegularExpression(QStringLiteral("m_[npb](?=[A-Z])")));
     description.remove(QStringLiteral("m_"));
     description.replace(QLatin1Char('\n'), QString(QStringLiteral("\n")) + m_indentation + QStringLiteral("# "));
 
