@@ -35,7 +35,7 @@ CodeGenOptionsPage::CodeGenOptionsPage(QWidget *parent)
 
     setupUi(this);
 
-    m_pCodePolicyPage = 0;
+    m_pCodePolicyPage = nullptr;
     m_parentPolicy = UMLApp::app()->commonPolicy();
     CodeGenerator* gen = UMLApp::app()->generator();
 
@@ -173,19 +173,19 @@ void CodeGenOptionsPage::updateCodeGenerationPolicyTab()
         m_pCodePolicyPage->disconnect();
 
         delete m_pCodePolicyPage;
-        m_pCodePolicyPage = 0;
+        m_pCodePolicyPage = nullptr;
     }
 
     Uml::ProgrammingLanguage::Enum pl = Uml::ProgrammingLanguage::fromInt(ui_SelectLanguageBox->currentIndex());
-    CodeGenPolicyExt *policyExt = 0;
+    CodeGenPolicyExt  *policyExt = nullptr;
     if (pl != Uml::ProgrammingLanguage::Reserved)
         policyExt = CodeGenFactory::newCodeGenPolicyExt(pl);
 
     if (policyExt) {
-        m_pCodePolicyPage = policyExt->createPage(0, "codelangpolicypage");
+        m_pCodePolicyPage = policyExt->createPage(nullptr, "codelangpolicypage");
     }
     else {
-        m_pCodePolicyPage = new DefaultCodeGenPolicyPage(0, "codelangpolicypage");
+        m_pCodePolicyPage = new DefaultCodeGenPolicyPage(nullptr, "codelangpolicypage");
     }
 
     ui_tabWidgetMain->insertTab(2, m_pCodePolicyPage, i18n("Language Options"));
@@ -224,8 +224,8 @@ void CodeGenOptionsPage::apply()
         // Emit in THIS order. The first signal triggers any sub-class to do its apply
         // slot, THEN, once we are all updated, we may sync the parent generator's code
         // documents.
-        emit applyClicked();
-        emit syncCodeDocumentsToParent();
+        Q_EMIT applyClicked();
+        Q_EMIT syncCodeDocumentsToParent();
     }
 }
 
@@ -250,13 +250,13 @@ bool CodeGenOptionsPage::save()
     if (info.exists()) {
         // directory exists... make sure we can write to it
         if (!info.isWritable()) {
-            KMessageBox::sorry(this, i18n("The output folder exists, but it is not writable.\nPlease set the appropriate permissions or choose another folder."),
+            KMessageBox::information(this, i18n("The output folder exists, but it is not writable.\nPlease set the appropriate permissions or choose another folder."),
                     i18n("Error Writing to Output Folder"));
             return false;
         }
         // it exits and we can write... make sure it is a directory
         if (!info.isDir()) {
-            KMessageBox::sorry(this, i18n("%1 does not seem to be a folder. Please choose a valid folder.", info.filePath()),
+            KMessageBox::information(this, i18n("%1 does not seem to be a folder. Please choose a valid folder.", info.filePath()),
                     i18n("Please Choose Valid Folder"));
             return false;
         }
@@ -268,7 +268,7 @@ bool CodeGenOptionsPage::save()
         {
             QDir dir;
             if (!dir.mkdir(info.filePath())) {
-                KMessageBox::sorry(this, i18n("The folder could not be created.\nPlease make sure you have write access to its parent folder or select another, valid, folder."),
+                KMessageBox::information(this, i18n("The folder could not be created.\nPlease make sure you have write access to its parent folder or select another, valid, folder."),
                             i18n("Error Creating Folder"));
                 return false;
             }
@@ -290,7 +290,7 @@ bool CodeGenOptionsPage::save()
 void CodeGenOptionsPage::activeLanguageChanged(int id)
 {
     Q_UNUSED(id);
-    emit languageChanged();
+    Q_EMIT languageChanged();
 }
 
 /**
