@@ -53,7 +53,7 @@ bool bNewUMLObjectWasCreated = false;
  * Related classifier for creation of dependencies on template
  * parameters in createUMLObject().
  */
-UMLClassifier * gRelatedClassifier = 0;
+UMLClassifier  *gRelatedClassifier = nullptr;
 
 /**
  * On encountering a scoped typename string where the scopes
@@ -122,11 +122,12 @@ QString formatComment(const QString &comment)
 
     QStringList lines = comment.split(QLatin1Char('\n'));
     QString& first = lines.first();
-    QRegExp wordex(QStringLiteral("\\w"));
+    QRegularExpression wordex(QStringLiteral("\\w"));
     if (first.startsWith(QStringLiteral("/*"))) {
-        int wordpos = wordex.indexIn(first);
-        if (wordpos != -1)
-            first = first.mid(wordpos);  // remove comment start
+        QRegularExpressionMatch match = wordex.match(first);
+
+        if (match.hasMatch())
+            first = first.mid(match.capturedStart());  // remove comment start
         else
             lines.pop_front();  // nothing interesting on this line
     }
@@ -146,8 +147,8 @@ QString formatComment(const QString &comment)
 
     QStringList::Iterator end(lines.end());
     for (QStringList::Iterator lit(lines.begin()); lit != end; ++lit) {
-        (*lit).remove(QRegExp(QStringLiteral("^\\s+")));
-        (*lit).remove(QRegExp(QStringLiteral("^\\*+\\s?")));
+        (*lit).remove(QRegularExpression(QStringLiteral("^\\s+")));
+        (*lit).remove(QRegularExpression(QStringLiteral("^\\*+\\s?")));
     }
     return lines.join(QStringLiteral("\n"));
 }
@@ -192,7 +193,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
     QString name = inName;
     UMLDoc *umldoc = UMLApp::app()->document();
     UMLFolder *logicalView = umldoc->rootFolder(Uml::ModelType::Logical);
-    if (parentPkg == 0) {
+    if (parentPkg == nullptr) {
         // logDebug1("Import_Utils::createUMLObject(%1): parentPkg is 0, assuming Logical View", name);
         parentPkg = logicalView;
     } else if (parentPkg->baseType() == UMLObject::ot_Artifact) {
@@ -218,7 +219,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
     }
     checkStdString(name);
     bNewUMLObjectWasCreated = false;
-    UMLObject *o = 0;
+    UMLObject  *o = nullptr;
     if (searchInParentPackageOnly) {
         o = Model_Utils::findUMLObject(parentPkg->containedObjects(), name, type);
         if (!o) {
@@ -229,34 +230,34 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
     } else {
         o = umldoc->findUMLObject(name, type, parentPkg);
     }
-    if (o == 0) {
+    if (o == nullptr) {
         // Strip possible adornments and look again.
         bool isConst = false;
-        if (name.contains(QRegExp(QStringLiteral("^const ")))) {
-            name.remove(QRegExp(QStringLiteral("^const\\s+")));
+        if (name.contains(QRegularExpression(QStringLiteral("^const ")))) {
+            name.remove(QRegularExpression(QStringLiteral("^const\\s+")));
             isConst = true;
         }
-        if (name.contains(QRegExp(QStringLiteral("\\bconst\\b")))) {
+        if (name.contains(QRegularExpression(QStringLiteral("\\bconst\\b")))) {
             // Here, we lose info of the exact placement of the `const` qualifier.
             // I argue that we are looking at a level of C++ detail that UML was not
             // designed for.  Feel free to disagree and implement this :)
-            name.remove(QRegExp(QStringLiteral("\\s+const\\b")));
-            name.remove(QRegExp(QStringLiteral("\\bconst\\s+")));
+            name.remove(QRegularExpression(QStringLiteral("\\s+const\\b")));
+            name.remove(QRegularExpression(QStringLiteral("\\bconst\\s+")));
             isConst = true;
         }
-        const bool isVolatile = name.contains(QRegExp(QStringLiteral("^volatile ")));
-        name.remove(QRegExp(QStringLiteral("^volatile\\s+")));
-        const bool isMutable = name.contains(QRegExp(QStringLiteral("^mutable ")));
-        name.remove(QRegExp(QStringLiteral("^mutable\\s+")));
+        const bool isVolatile = name.contains(QRegularExpression(QStringLiteral("^volatile ")));
+        name.remove(QRegularExpression(QStringLiteral("^volatile\\s+")));
+        const bool isMutable = name.contains(QRegularExpression(QStringLiteral("^mutable ")));
+        name.remove(QRegularExpression(QStringLiteral("^mutable\\s+")));
         QString typeName(name);
-        bool isAdorned = typeName.contains(QRegExp(QStringLiteral("[^\\w:\\. ]")));
+        bool isAdorned = typeName.contains(QRegularExpression(QStringLiteral("[^\\w:\\. ]")));
         const bool isPointer = typeName.contains(QLatin1Char('*'));
         const bool isRef = typeName.contains(QLatin1Char('&'));
-        typeName.remove(QRegExp(QStringLiteral("[^\\w:\\. ].*$")));
+        typeName.remove(QRegularExpression(QStringLiteral("[^\\w:\\. ].*$")));
         typeName = typeName.simplified();
         checkStdString(typeName);
         UMLObject *origType = umldoc->findUMLObject(typeName, UMLObject::ot_UMLObject, parentPkg);
-        if (origType == 0) {
+        if (origType == nullptr) {
             // Still not found. Create the stripped down type.
             if (bPutAtGlobalScope)
                 parentPkg = logicalView;
@@ -315,7 +316,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
             o = Object_Factory::createUMLObject(UMLObject::ot_Datatype, name,
                                                 umldoc->datatypeFolder(),
                                                 false); //solicitNewName
-            UMLDatatype *dt = o ? o->asUMLDatatype() : 0;
+            UMLDatatype *dt = o ? o->asUMLDatatype() : nullptr;
             UMLClassifier *c = origType->asUMLClassifier();
             if (dt && c)
                 dt->setOriginType(c);
@@ -358,21 +359,22 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
     if (o && !stereotype.isEmpty()) {
         o->setStereotype(stereotype);
     }
-    if (gRelatedClassifier == 0 || gRelatedClassifier == o)
+    if (gRelatedClassifier == nullptr || gRelatedClassifier == o)
         return o;
-    QRegExp templateInstantiation(QStringLiteral("^[\\w:\\.]+\\s*<(.*)>"));
-    int pos = templateInstantiation.indexIn(name);
-    if (pos == -1)
+    QRegularExpression templateInstantiation(QStringLiteral("^[\\w:\\.]+\\s*<(.*)>"));
+    QRegularExpressionMatch match = templateInstantiation.match(name);
+
+    if (!match.hasMatch())
         return o;
     // Create dependencies on template parameters.
-    QString caption = templateInstantiation.cap(1);
-    const QStringList params = caption.split(QRegExp(QStringLiteral("[^\\w:\\.]+")));
+    QString caption = match.captured();
+    const QStringList params = caption.split(QRegularExpression(QStringLiteral("[^\\w:\\.]+")));
     if (!params.count())
         return o;
     QStringList::ConstIterator end(params.end());
     for (QStringList::ConstIterator it(params.begin()); it != end; ++it) {
         UMLObject *p = umldoc->findUMLObject(*it, UMLObject::ot_UMLObject, parentPkg);
-        if (p == 0 || p->isUMLDatatype())
+        if (p == nullptr || p->isUMLDatatype())
             continue;
         const Uml::AssociationType::Enum at = Uml::AssociationType::Dependency;
         UMLAssociation *assoc = umldoc->findAssociation(at, gRelatedClassifier, p);
@@ -382,7 +384,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
         assoc->setUMLPackage(umldoc->rootFolder(Uml::ModelType::Logical));
         umldoc->addAssociation(assoc);
     }
-    if (o == 0) {
+    if (o == nullptr) {
         logError1("Import_Utils::createUMLObject(%1) : operation failed", inName);
     }
     return o;
@@ -408,7 +410,7 @@ UMLObject* createUMLObjectHierarchy(UMLObject::ObjectType type, const QString &n
     if (name.contains(scopeSeparator)) {
         QStringList components =  name.split(scopeSeparator);
         objectName = components.takeLast();
-        foreach(const QString scopeName, components) {
+        for(const QString scopeName : components) {
             o = parent->findObject(scopeName);
             if (o && (o->isUMLPackage() || o->isUMLClassifier())) {
                 parent = o->asUMLPackage();
@@ -462,7 +464,7 @@ UMLAttribute* insertAttribute(UMLClassifier *owner,
            (ot == UMLObject::ot_Interface && pl == Uml::ProgrammingLanguage::Java))) {
         logDebug2("Import_Utils::insertAttribute: Don't know what to do with %1 (object type %2)",
                   owner->name(), UMLObject::toString(ot));
-        return 0;
+        return nullptr;
     }
     UMLObject *o = owner->findChildObject(name, UMLObject::ot_Attribute);
     if (o) {
@@ -490,11 +492,11 @@ UMLAttribute *insertAttribute(UMLClassifier *owner, Uml::Visibility::Enum scope,
                            bool isStatic /* =false */)
 {
     UMLObject *attrType = owner->findTemplate(type);
-    if (attrType == 0) {
+    if (attrType == nullptr) {
         bPutAtGlobalScope = true;
         gRelatedClassifier = owner;
         attrType = createUMLObject(UMLObject::ot_UMLObject, type, owner);
-        gRelatedClassifier = 0;
+        gRelatedClassifier = nullptr;
         bPutAtGlobalScope = false;
     }
     return insertAttribute (owner, scope, name,
@@ -534,11 +536,11 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
             op->setType(klass);
         } else {
             UMLObject *typeObj = klass->findTemplate(type);
-            if (typeObj == 0) {
+            if (typeObj == nullptr) {
                 bPutAtGlobalScope = true;
                 gRelatedClassifier = klass;
                 typeObj = createUMLObject(UMLObject::ot_UMLObject, type, klass);
-                gRelatedClassifier = 0;
+                gRelatedClassifier = nullptr;
                 bPutAtGlobalScope = false;
                 op->setType(typeObj);
             }
@@ -598,12 +600,12 @@ UMLAttribute* addMethodParameter(UMLOperation *method,
                                  const QString& name)
 {
     UMLClassifier *owner = method->umlParent()->asUMLClassifier();
-    UMLObject *typeObj = owner ? owner->findTemplate(type) : 0;
-    if (typeObj == 0) {
+    UMLObject *typeObj = owner ? owner->findTemplate(type) : nullptr;
+    if (typeObj == nullptr) {
         bPutAtGlobalScope = true;
         gRelatedClassifier = owner;
         typeObj = createUMLObject(UMLObject::ot_UMLObject, type, owner);
-        gRelatedClassifier = 0;
+        gRelatedClassifier = nullptr;
         bPutAtGlobalScope = false;
     }
     UMLAttribute *attr = Object_Factory::createAttribute(method, name, typeObj);
@@ -732,13 +734,13 @@ UMLObject *createArtifact(const QString& name,
 void createGeneralization(UMLClassifier *child, const QString &parentName)
 {
     const QString& scopeSep = UMLApp::app()->activeLanguageScopeSeparator();
-    UMLObject *parentObj = 0;
+    UMLObject  *parentObj = nullptr;
     if (parentName.contains(scopeSep)) {
         QStringList split = parentName.split(scopeSep);
         QString className = split.last();
         split.pop_back(); // remove the classname
-        UMLPackage *parent = 0;
-        UMLPackage *current = 0;
+        UMLPackage  *parent = nullptr;
+        UMLPackage  *current = nullptr;
         for (QStringList::Iterator it = split.begin(); it != split.end(); ++it) {
             QString name = (*it);
             UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Package,
@@ -769,27 +771,27 @@ void createGeneralization(UMLClassifier *child, const QString &parentName)
  */
 UMLEnum *remapUMLEnum(UMLObject *ns, UMLPackage *currentScope)
 {
-    if (ns == 0) {
-        return 0;
+    if (ns == nullptr) {
+        return nullptr;
     }
     QString comment = ns->doc();
     QString name = ns->name();
     QString stereotype = ns->stereotype();
     Uml::Visibility::Enum visibility = ns->visibility();
     UMLApp::app()->document()->removeUMLObject(ns, true);
-    if (currentScope == 0)
+    if (currentScope == nullptr)
         currentScope = UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical);
     UMLObject *o = Object_Factory::createNewUMLObject(UMLObject::ot_Enum, name, currentScope, false);
     if (!o) {
         logDebug1("Import_Utils::remapUMLEnum(%1) : Object_Factory::createNewUMLObject(ot_Enum) returns null",
                   name);
-        return 0;
+        return nullptr;
     }
     UMLEnum *e = o->asUMLEnum();
     if (!e) {
         logDebug1("Import_Utils::remapUMLEnum(%1) : object returned by Object_Factory::createNewUMLObject "
                   "is not Enum", name);
-        return 0;
+        return nullptr;
     }
     e->setDoc(comment);
     e->setStereotypeCmd(stereotype.isEmpty() ? QStringLiteral("enum") : stereotype);
@@ -798,7 +800,7 @@ UMLEnum *remapUMLEnum(UMLObject *ns, UMLPackage *currentScope)
     if (currentScope->addObject(e, false))  // false => non interactively
         return e;
     logDebug2("Import_Utils::remapUMLEnum(%1) : name is already present in %2", name, currentScope->name());
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -833,7 +835,7 @@ bool isDatatype(const QString& name, UMLPackage *parentPkg)
 {
     UMLDoc *umldoc = UMLApp::app()->document();
     UMLObject * o = umldoc->findUMLObject(name, UMLObject::ot_Datatype, parentPkg);
-    return (o != 0);
+    return (o != nullptr);
 }
 
 /**
