@@ -209,7 +209,7 @@ bool Tracer::logToConsole()
  * @param state  initial enabled state
  * @param filePath  path qualified source filename of class
  */
-void Tracer::registerClass(const char * name, bool state, const char * filePath /* = 0 */)
+void Tracer::registerClass(const char  *name, bool state, const char * filePath /* = nullptr */)
 {
     if (n_clients >= MAX_TRACERCLIENTS) {
         uError() << "Tracer::registerClass : MAX_TRACERCLIENTS is exceeded";
@@ -221,7 +221,7 @@ void Tracer::registerClass(const char * name, bool state, const char * filePath
     if (filePath)
         client.filePath = strdup(filePath);
     else
-        client.filePath = 0;
+        client.filePath = nullptr;
     n_clients++;
 }
 
@@ -234,7 +234,7 @@ void Tracer::update(const QString &name)
     if (!isVisible())
         return;
     QList<QTreeWidgetItem*> items = findItems(name, Qt::MatchFixedString);
-    foreach(QTreeWidgetItem* item, items) {
+    for(QTreeWidgetItem *item : items) {
         item->setCheckState(0, (*s_classes)[name].state ? Qt::Checked : Qt::Unchecked);
     }
 }
@@ -272,7 +272,7 @@ void Tracer::showEvent(QShowEvent* e)
     MapType::const_iterator i = s_classes->constBegin();
     for(; i != s_classes->constEnd(); i++) {
         QList<QTreeWidgetItem*> items = findItems(i.value().filePath, Qt::MatchFixedString);
-        QTreeWidgetItem* topLevel = nullptr;
+        QTreeWidgetItem *topLevel = nullptr;
         if (items.size() == 0) {
             topLevel = new QTreeWidgetItem(QStringList(i.value().filePath));
             topLevel->setFlags(Qt::ItemIsSelectable | Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
