@@ -1,14 +1,9 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003-2020                                               *
- *   Brian Thomas <brian.thomas@gsfc.nasa.gov>                             *
- *   copyright (C) 2004-2020                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2003-2020 Brian Thomas <brian.thomas@gsfc.nasa.gov>
+    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef CODEVIEWERDIALOG_H
 #define CODEVIEWERDIALOG_H
@@ -49,9 +44,9 @@ private:
 
     void initGUI();
 
-public slots:
+public Q_SLOTS:
 
-protected slots:
+protected Q_SLOTS:
 
     virtual void languageChange();
 
