@@ -24,7 +24,7 @@ public:
     void setDefaults();
     void apply();
 
-signals:
+Q_SIGNALS:
     void applyClicked();
 
 protected:
