@@ -163,7 +163,7 @@ void SelectOperationPage::slotNewOperation()
         return;
     setupOperationsList();
     setClassOp(op->toString(Uml::SignatureType::SigNoVis));
-    emit enableButtonOk(true);
+    Q_EMIT enableButtonOk(true);
 }
 
 /**
@@ -174,10 +174,10 @@ void SelectOperationPage::slotIndexChanged(int index)
     if (index != -1) {
         m_pOpLE->setText(QString());
         m_id = OP;
-        emit enableButtonOk(true);
+        Q_EMIT enableButtonOk(true);
     }
     if (m_pOpCB->currentText().isEmpty()) {
-        emit enableButtonOk(false);
+        Q_EMIT enableButtonOk(false);
     }
 }
 
@@ -187,12 +187,12 @@ void SelectOperationPage::slotIndexChanged(int index)
 void SelectOperationPage::slotTextChanged(const QString &text)
 {
     if (text.isEmpty()) {
-        emit enableButtonOk(false);
+        Q_EMIT enableButtonOk(false);
     }
     else {
         m_pOpCB->setCurrentIndex(-1);
         m_id = CUSTOM;
-        emit enableButtonOk(true);
+        Q_EMIT enableButtonOk(true);
     }
 }
 
@@ -223,8 +223,8 @@ void SelectOperationPage::setupOperationsList()
     UMLOperationList list = m_classifier->getOpList(true);
     if (list.count() > 0)
         m_pOpCB->insertItem(0, QString());
-    qSort(list.begin(), list.end(), caseInsensitiveLessThan);
-    foreach(UMLOperation * obj, list) {
+    std::sort(list.begin(), list.end(), caseInsensitiveLessThan);
+    for(UMLOperation * obj : list) {
         QString s = obj->toString(Uml::SignatureType::SigNoVis);
         m_pOpCB->insertItem(list.count(), s);
         m_pOpCB->completionObject()->addItem(s);
@@ -280,12 +280,12 @@ void SelectOperationPage::setupDialog()
    } else
         setSeqNumber(m_widget->sequenceNumber());
 
-    if (m_widget->operation() == 0) {
+    if (m_widget->operation() == nullptr) {
         setCustomOp(m_widget->lwOperationText());
     } else {
         setClassOp(m_widget->lwOperationText());
     }
-    emit enableButtonOk(false);
+    Q_EMIT enableButtonOk(false);
 }
 
 /**
@@ -304,8 +304,8 @@ bool SelectOperationPage::apply()
         if (st == Model_Utils::PS_OK) {
             UMLClassifierList selfAndAncestors = m_classifier->findSuperClassConcepts();
             selfAndAncestors.prepend(m_classifier);
-            UMLOperation *op = 0;
-            foreach (UMLClassifier *cl, selfAndAncestors) {
+            UMLOperation *op = nullptr;
+            for(UMLClassifier *cl : selfAndAncestors) {
                 op = cl->findOperation(od.m_name, od.m_args);
                 if (op) {
                     break;
@@ -313,7 +313,7 @@ bool SelectOperationPage::apply()
             }
             if (!op) {
                 // The op does not yet exist. Create a new one.
-                UMLObject *o = m_classifier->createOperation(od.m_name, 0, &od.m_args);
+                UMLObject *o = m_classifier->createOperation(od.m_name, nullptr, &od.m_args);
                 op = o->asUMLOperation();
             }
             if (od.m_pReturnType) {
@@ -323,10 +323,10 @@ bool SelectOperationPage::apply()
             m_widget->setOperation(op);
             opText.clear();
         } else {
-            m_widget->setOperation(0);
+            m_widget->setOperation(nullptr);
         }
     } else {
-        m_widget->setOperation(0);
+        m_widget->setOperation(nullptr);
     }
     m_widget->setSequenceNumber(getSeqNumber());
     m_widget->setOperationText(opText);
