@@ -39,7 +39,7 @@ UMLPackageWidget::UMLPackageWidget(UMLObject *o, QWidget *parent) :
     Uml::ModelType::Enum guess = Model_Utils::guessContainer(o);
     UMLPackageList packageList = UMLApp::app()->document()->packages(true, guess);
     QStringList packages;
-    foreach(UMLPackage* package, packageList) {
+    for(UMLPackage* package : packageList) {
         packages << package->name();
     }
     packages.sort();
@@ -49,7 +49,7 @@ UMLPackageWidget::UMLPackageWidget(UMLObject *o, QWidget *parent) :
 
     UMLPackage* folderLogicalView =
             UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical)->asUMLPackage();
-    if (parentPackage == 0 ||
+    if (parentPackage == nullptr ||
          parentPackage == folderLogicalView) {
         m_editField->setEditText(QString());
     }
@@ -82,10 +82,10 @@ void UMLPackageWidget::addToLayout(QGridLayout *layout, int row)
 void UMLPackageWidget::apply()
 {
     QString packageName = m_editField->currentText().trimmed();
-    UMLObject* newPackage = 0;
+    UMLObject *newPackage = nullptr;
 
     if (!packageName.isEmpty()) {
-        if ((newPackage = UMLApp::app()->document()->findUMLObject(packageName, UMLObject::ot_Package)) == 0) {
+        if ((newPackage = UMLApp::app()->document()->findUMLObject(packageName, UMLObject::ot_Package)) == nullptr) {
             newPackage = Import_Utils::createUMLObject(UMLObject::ot_Package, packageName);
         }
     } else {
