@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2015-2021                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2015-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef STEREOTYPESMODEL_H
 #define STEREOTYPESMODEL_H
@@ -16,8 +11,7 @@
 
 // qt includes
 #include <QAbstractTableModel>
-
-class UMLStereotype;
+#include "stereotype.h"
 
 Q_DECLARE_METATYPE(UMLStereotype*);
 
