@@ -37,7 +37,7 @@ DEBUG_REGISTER(UMLEntity)
  */
 UMLEntity::UMLEntity(const QString& name, Uml::ID::Type id)
   : UMLClassifier(name, id),
-    m_PrimaryKey(0)
+    m_PrimaryKey(nullptr)
 {
     m_BaseType = UMLObject::ot_Entity;
     connect(this, SIGNAL(entityAttributeRemoved(UMLClassifierListItem*)),
@@ -94,7 +94,7 @@ UMLObject* UMLEntity::clone() const
  * @param iv     the initial value for the attribute
  * @return   the just created attribute or null 
  */
-UMLAttribute* UMLEntity::createAttribute(const QString &name /*= QString()*/, UMLObject *type /*= 0*/,
+UMLAttribute *UMLEntity::createAttribute(const QString &name /*= QString()*/, UMLObject *type /*= nullptr*/,
                                          Uml::Visibility::Enum vis /* = Uml::Visibility::Private*/,
                                          const QString& iv /* = QString()*/)
 {
@@ -114,14 +114,14 @@ UMLAttribute* UMLEntity::createAttribute(const QString &name /*= QString()*/, UM
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
     while (button == QDialog::Accepted && !goodName && name.isNull()) {
-        QPointer<UMLEntityAttributeDialog> dialog = new UMLEntityAttributeDialog(0, newAttribute);
+        QPointer<UMLEntityAttributeDialog> dialog = new UMLEntityAttributeDialog(nullptr, newAttribute);
         button = dialog->exec();
         QString name = newAttribute->name();
 
         if (name.length() == 0) {
-            KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
-        } else if (findChildObject(name) != 0) {
-            KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
+            KMessageBox::error(nullptr, i18n("That is an invalid name."), i18n("Invalid Name"));
+        } else if (findChildObject(name) != nullptr) {
+            KMessageBox::error(nullptr, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
@@ -130,7 +130,7 @@ UMLAttribute* UMLEntity::createAttribute(const QString &name /*= QString()*/, UM
 
     if (button != QDialog::Accepted) {
         delete newAttribute;
-        return 0;
+        return nullptr;
     }
 
     addEntityAttribute(newAttribute);
@@ -167,14 +167,14 @@ UMLUniqueConstraint* UMLEntity::createUniqueConstraint(const QString &name)
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
     while (button == QDialog::Accepted && !goodName && name.isNull()) {
-        QPointer<UMLUniqueConstraintDialog> dialog = new UMLUniqueConstraintDialog(0, newUniqueConstraint);
+        QPointer<UMLUniqueConstraintDialog> dialog = new UMLUniqueConstraintDialog(nullptr, newUniqueConstraint);
         button = dialog->exec();
         QString name = newUniqueConstraint->name();
 
         if (name.length() == 0) {
-            KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
-        } else if (findChildObject(name) != 0) {
-            KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
+            KMessageBox::error(nullptr, i18n("That is an invalid name."), i18n("Invalid Name"));
+        } else if (findChildObject(name) != nullptr) {
+            KMessageBox::error(nullptr, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
@@ -183,7 +183,7 @@ UMLUniqueConstraint* UMLEntity::createUniqueConstraint(const QString &name)
 
     if (button != QDialog::Accepted) {
         delete newUniqueConstraint;
-        return 0;
+        return nullptr;
     }
 
     addConstraint(newUniqueConstraint);
@@ -217,14 +217,14 @@ UMLForeignKeyConstraint* UMLEntity::createForeignKeyConstraint(const QString &na
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
     while (button == QDialog::Accepted && !goodName && name.isNull()) {
-        QPointer<UMLForeignKeyConstraintDialog> dialog = new UMLForeignKeyConstraintDialog(0, newForeignKeyConstraint);
+        QPointer<UMLForeignKeyConstraintDialog> dialog = new UMLForeignKeyConstraintDialog(nullptr, newForeignKeyConstraint);
         button = dialog->exec();
         QString name = newForeignKeyConstraint->name();
 
         if (name.length() == 0) {
-            KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
-        } else if (findChildObject(name) != 0) {
-            KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
+            KMessageBox::error(nullptr, i18n("That is an invalid name."), i18n("Invalid Name"));
+        } else if (findChildObject(name) != nullptr) {
+            KMessageBox::error(nullptr, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
@@ -232,7 +232,7 @@ UMLForeignKeyConstraint* UMLEntity::createForeignKeyConstraint(const QString &na
     }
 
     if (button != QDialog::Accepted) {
-        return 0;
+        return nullptr;
     }
 
     addConstraint(newForeignKeyConstraint);
@@ -266,14 +266,14 @@ UMLCheckConstraint* UMLEntity::createCheckConstraint(const QString &name)
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
     while (button == QDialog::Accepted && !goodName && name.isNull()) {
-        QPointer<UMLCheckConstraintDialog> dialog = new UMLCheckConstraintDialog(0, newCheckConstraint);
+        QPointer<UMLCheckConstraintDialog> dialog = new UMLCheckConstraintDialog(nullptr, newCheckConstraint);
         button = dialog->exec();
         QString name = newCheckConstraint->name();
 
         if (name.length() == 0) {
-            KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
-        } else if (findChildObject(name) != 0) {
-            KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
+            KMessageBox::error(nullptr, i18n("That is an invalid name."), i18n("Invalid Name"));
+        } else if (findChildObject(name) != nullptr) {
+            KMessageBox::error(nullptr, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
@@ -281,7 +281,7 @@ UMLCheckConstraint* UMLEntity::createCheckConstraint(const QString &name)
     }
 
     if (button != QDialog::Accepted) {
-        return 0;
+        return nullptr;
     }
 
     addConstraint(newCheckConstraint);
@@ -303,7 +303,7 @@ UMLObject* UMLEntity::addEntityAttribute(const QString& name, Uml::ID::Type id)
 {
     UMLEntityAttribute* literal = new UMLEntityAttribute(this, name, id);
     subordinates().append(literal);
-    emit entityAttributeAdded(literal);
+    Q_EMIT entityAttributeAdded(literal);
     UMLObject::emitModified();
     connect(literal, SIGNAL(modified()), this, SIGNAL(modified()));
     return literal;
@@ -316,13 +316,13 @@ UMLObject* UMLEntity::addEntityAttribute(const QString& name, Uml::ID::Type id)
  * @param log   Pointer to the IDChangeLog.
  * @return  True if the entityAttribute was successfully added.
  */
-bool UMLEntity::addEntityAttribute(UMLEntityAttribute* att, IDChangeLog* log /* = 0*/)
+bool UMLEntity::addEntityAttribute(UMLEntityAttribute *att, IDChangeLog* log /* = nullptr*/)
 {
     QString name = (QString)att->name();
-    if (findChildObject(name) == 0) {
+    if (findChildObject(name) == nullptr) {
         att->setParent(this);
         subordinates().append(att);
-        emit entityAttributeAdded(att);
+        Q_EMIT entityAttributeAdded(att);
         UMLObject::emitModified();
         connect(att, SIGNAL(modified()), this, SIGNAL(modified()));
         return true;
@@ -346,14 +346,14 @@ bool UMLEntity::addEntityAttribute(UMLEntityAttribute* att, int position)
 {
     Q_ASSERT(att);
     QString name = (QString)att->name();
-    if (findChildObject(name) == 0) {
+    if (findChildObject(name) == nullptr) {
         att->setParent(this);
         if (position >= 0 && position <= (int)subordinates().count())  {
             subordinates().insert(position, att);
         } else {
             subordinates().append(att);
         }
-        emit entityAttributeAdded(att);
+        Q_EMIT entityAttributeAdded(att);
         UMLObject::emitModified();
         connect(att, SIGNAL(modified()), this, SIGNAL(modified()));
         return true;
@@ -373,7 +373,7 @@ int UMLEntity::removeEntityAttribute(UMLClassifierListItem* att)
         logDebug0("UMLEntity::removeEntityAttribute cannot find att given in list");
         return -1;
     }
-    emit entityAttributeRemoved(att);
+    Q_EMIT entityAttributeRemoved(att);
     UMLObject::emitModified();
     // If we are deleting the object, then we don't need to disconnect..this is done auto-magically
     // for us by QObject. -b.t.
@@ -397,7 +397,7 @@ int UMLEntity::entityAttributes() const
  */
 void UMLEntity::signalEntityAttributeRemoved(UMLClassifierListItem *eattr)
 {
-    emit entityAttributeRemoved(eattr);
+    Q_EMIT entityAttributeRemoved(eattr);
 }
 
 /**
@@ -407,18 +407,18 @@ void UMLEntity::signalEntityAttributeRemoved(UMLClassifierListItem *eattr)
 bool UMLEntity::resolveRef()
 {
     bool success = UMLClassifier::resolveRef();
-    foreach (UMLObject *obj, subordinates()) {
+    for(UMLObject *obj : subordinates()) {
         if (obj->resolveRef()) {
             UMLClassifierListItem *cli = obj->asUMLClassifierListItem();
             if (!cli)
                 return success;
             switch (cli->baseType()) {
                 case UMLObject::ot_EntityAttribute:
-                    emit entityAttributeAdded(cli);
+                    Q_EMIT entityAttributeAdded(cli);
                     break;
                 case UMLObject::ot_UniqueConstraint:
                 case UMLObject::ot_ForeignKeyConstraint:
-                    emit entityConstraintAdded(cli);
+                    Q_EMIT entityConstraintAdded(cli);
                     break;
                 default:
                     break;
@@ -437,13 +437,13 @@ void UMLEntity::saveToXMI(QXmlStreamWriter& writer)
 
     // save entity attributes
     UMLClassifierListItemList entityAttributes = getFilteredList(UMLObject::ot_EntityAttribute);
-    UMLClassifierListItem* pEntityAttribute = 0;
-    foreach (pEntityAttribute, entityAttributes) {
+    
+    for(UMLClassifierListItem *pEntityAttribute: entityAttributes) {
         pEntityAttribute->saveToXMI(writer);
     }
     // save entity constraints
     UMLClassifierListItemList entityConstraints = getFilteredList(UMLObject::ot_EntityConstraint);
-    foreach(UMLClassifierListItem* cli, entityConstraints) {
+    for(UMLClassifierListItem *cli : entityConstraints) {
         cli->saveToXMI(writer);
     }
 
@@ -512,7 +512,7 @@ bool UMLEntity::load1(QDomElement& element)
  */
 bool UMLEntity::setAsPrimaryKey(UMLUniqueConstraint* uconstr)
 {
-    if (uconstr == 0) {
+    if (uconstr == nullptr) {
         logWarn0("UMLEntity::setAsPrimaryKey: NULL value passed. To unset a Primary Key use "
                   "unsetPrimaryKey()");
         return false;
@@ -527,8 +527,8 @@ bool UMLEntity::setAsPrimaryKey(UMLUniqueConstraint* uconstr)
 
     // check if this constraint already exists as a unique constraint for this entity
     UMLObject *o = findChildObjectById(uconstr->id());
-    UMLUniqueConstraint* uuc = o ? o->asUMLUniqueConstraint() : 0;
-    if (uuc == 0) {
+    UMLUniqueConstraint* uuc = o ? o->asUMLUniqueConstraint() : nullptr;
+    if (uuc == nullptr) {
         addConstraint(uconstr);
         uuc = uconstr;
     }
@@ -537,7 +537,7 @@ bool UMLEntity::setAsPrimaryKey(UMLUniqueConstraint* uconstr)
 
     m_PrimaryKey = uuc;
 
-    if (oldPrimaryKey != 0)
+    if (oldPrimaryKey != nullptr)
         oldPrimaryKey->emitModified();
 
     uuc->emitModified();
@@ -552,7 +552,7 @@ bool UMLEntity::setAsPrimaryKey(UMLUniqueConstraint* uconstr)
  */
 void UMLEntity::unsetPrimaryKey()
 {
-    m_PrimaryKey = 0;
+    m_PrimaryKey = nullptr;
 }
 
 /**
@@ -576,7 +576,7 @@ bool UMLEntity::hasPrimaryKey() const
  */
 bool UMLEntity::addConstraint(UMLEntityConstraint* constr)
 {
-    if (findChildObjectById(constr->id()) != 0) {
+    if (findChildObjectById(constr->id()) != nullptr) {
         logDebug1("UMLEntity::addConstraint: Constraint with id %1 already exists",
                   Uml::ID::toString(constr->id()));
         return false;
@@ -584,7 +584,7 @@ bool UMLEntity::addConstraint(UMLEntityConstraint* constr)
 
     subordinates().append(constr);
 
-    emit entityConstraintAdded(constr);
+    Q_EMIT entityConstraintAdded(constr);
     UMLObject::emitModified();
     connect(constr, SIGNAL(modified()), this, SIGNAL(modified()));
 
@@ -599,7 +599,7 @@ bool UMLEntity::addConstraint(UMLEntityConstraint* constr)
  */
 bool UMLEntity::removeConstraint(UMLEntityConstraint* constr)
 {
-     if (findChildObjectById(constr->id()) == 0) {
+     if (findChildObjectById(constr->id()) == nullptr) {
         logDebug1("UMLEntity::removeConstraint: Constraint with id %1 does not exist",
                   Uml::ID::toString(constr->id()));
         return false;
@@ -611,7 +611,7 @@ bool UMLEntity::removeConstraint(UMLEntityConstraint* constr)
 
     subordinates().removeAll(constr);
 
-    emit entityConstraintRemoved(constr);
+    Q_EMIT entityConstraintRemoved(constr);
     UMLObject::emitModified();
 
     delete constr;
@@ -630,7 +630,7 @@ void UMLEntity::slotEntityAttributeRemoved(UMLClassifierListItem* cli)
     if (cli) {
        UMLClassifierListItemList ual = this->getFilteredList(UMLObject::ot_UniqueConstraint);
 
-       foreach(UMLClassifierListItem* ucli,  ual) {
+       for(UMLClassifierListItem *ucli :  ual) {
            UMLUniqueConstraint* uuc = ucli->asUMLUniqueConstraint();
            if (uuc->hasEntityAttribute(entAtt)) {
                uuc->removeEntityAttribute(entAtt);
@@ -653,23 +653,22 @@ UMLClassifierListItemList UMLEntity::getFilteredList(UMLObject::ObjectType ot) c
 
         // append the lists to rcList
         // first the Unique Constraints
-        foreach(UMLClassifierListItem* ucli, ucList) {
+        for(UMLClassifierListItem *ucli : ucList) {
             rcList.append(ucli);
         }
 
         // then the Foreign Key Constraints
-        foreach(UMLClassifierListItem* ucli, fcList) {
+        for(UMLClassifierListItem *ucli : fcList) {
             rcList.append(ucli);
         }
 
-        foreach(UMLClassifierListItem* ucli, ccList) {
+        for(UMLClassifierListItem *ucli : ccList) {
             rcList.append(ucli);
         }
 
         return rcList;
-    } else {
-        return UMLClassifier::getFilteredList(ot);
     }
+    return UMLClassifier::getFilteredList(ot);
 }
 
 /**
@@ -693,7 +692,7 @@ bool UMLEntity::isPrimaryKey(const UMLUniqueConstraint* uConstr) const
 UMLEntityAttributeList UMLEntity::getEntityAttributes() const
 {
     UMLEntityAttributeList entityAttributeList;
-    foreach (UMLObject *listItem, subordinates()) {
+    for(UMLObject  *listItem : subordinates()) {
         if (listItem->baseType() == UMLObject::ot_EntityAttribute) {
             entityAttributeList.append(listItem->asUMLEntityAttribute());
         }
@@ -712,7 +711,7 @@ UMLEntityAttributeList UMLEntity::getEntityAttributes() const
  */
 UMLClassifierListItem* UMLEntity::makeChildObject(const QString& xmiTag)
 {
-    UMLClassifierListItem* pObject = 0;
+    UMLClassifierListItem *pObject = nullptr;
     if (UMLDoc::tagEq(xmiTag, QStringLiteral("EntityAttribute"))) {
         pObject = new UMLEntityAttribute(this);
     }
