@@ -105,7 +105,7 @@ void UMLFolder::removeView(UMLView *view)
 void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested)
 {
     if (includeNested) {
-        foreach (UMLObject* o, m_objects) {
+        for(UMLObject* o : m_objects) {
             uIgnoreZeroPointer(o);
             if (o->baseType() == UMLObject::ot_Folder) {
                 UMLFolder *f = o->asUMLFolder();
@@ -113,7 +113,7 @@ void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested)
             }
         }
     }
-    foreach (UMLView* v, m_diagrams) {
+    for(UMLView* v : m_diagrams) {
         viewList.append(v);
     }
 }
@@ -125,7 +125,7 @@ void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested)
  */
 void UMLFolder::activateViews()
 {
-    foreach (UMLObject* o, m_objects) {
+    for(UMLObject* o : m_objects) {
         uIgnoreZeroPointer(o);
         if (o->baseType() == UMLObject::ot_Folder) {
             UMLFolder *f = o->asUMLFolder();
@@ -133,7 +133,7 @@ void UMLFolder::activateViews()
         }
     }
 
-    foreach (UMLView* v, m_diagrams) {
+    for(UMLView* v : m_diagrams) {
         UMLScene *scene = v->umlScene();
         scene->activateAfterLoad();
         uDebug() << "UMLFolder::activateViews: " << scene->name() << " sceneRect = " << scene->sceneRect();
@@ -154,16 +154,16 @@ void UMLFolder::activateViews()
  */
 UMLView *UMLFolder::findView(Uml::ID::Type id)
 {
-    foreach (UMLView* v, m_diagrams) {
+    for(UMLView* v : m_diagrams) {
         if (v && v->umlScene() && v->umlScene()->ID() == id) {
             return v;
         }
     }
 
-    UMLView* v = 0;
+    UMLView *v = nullptr;
     UMLPackageList packages;
     appendPackages(packages);
-    foreach (UMLPackage *o, packages) {
+    for(UMLPackage *o : packages) {
         if (o->baseType() != UMLObject::ot_Folder) {
             continue;
         }
@@ -185,15 +185,15 @@ UMLView *UMLFolder::findView(Uml::ID::Type id)
  */
 UMLView *UMLFolder::findView(Uml::DiagramType::Enum type, const QString &name, bool searchAllScopes)
 {
-    foreach (UMLView* v, m_diagrams) {
+    for(UMLView *v : m_diagrams) {
         if (v->umlScene()->type() == type && v->umlScene()->name() == name) {
             return v;
         }
     }
 
-    UMLView* v = 0;
+    UMLView *v = nullptr;
     if (searchAllScopes) {
-        foreach (UMLObject* o, m_objects) {
+        for(UMLObject *o : m_objects) {
             uIgnoreZeroPointer(o);
             if (o->baseType() != UMLObject::ot_Folder) {
                 continue;
@@ -214,7 +214,7 @@ UMLView *UMLFolder::findView(Uml::DiagramType::Enum type, const QString &name, b
 void UMLFolder::setViewOptions(const Settings::OptionState& optionState)
 {
     // for each view update settings
-    foreach (UMLView* v, m_diagrams) {
+    for(UMLView *v : m_diagrams) {
         v->umlScene()->setOptionState(optionState);
     }
 }
@@ -224,7 +224,7 @@ void UMLFolder::setViewOptions(const Settings::OptionState& optionState)
  */
 void UMLFolder::removeAllViews()
 {
-    foreach (UMLObject* o, m_objects) {
+    for(UMLObject *o : m_objects) {
         uIgnoreZeroPointer(o);
         if (o->baseType() != UMLObject::ot_Folder)
             continue;
@@ -232,7 +232,7 @@ void UMLFolder::removeAllViews()
         f->removeAllViews();
     }
 
-    foreach (UMLView* v, m_diagrams) {
+    for(UMLView *v : m_diagrams) {
         // TODO ------------------ check this code - bad: calling back to UMLDoc::removeView()
         v->umlScene()->removeAllAssociations(); // note : It may not be apparent, but when we remove all associations
         // from a view, it also causes any UMLAssociations that lack parent
@@ -273,12 +273,12 @@ void UMLFolder::saveContents(QXmlStreamWriter& writer)
         writer.writeStartElement(QStringLiteral("UML:Namespace.ownedElement"));
     }
     // Save contained objects if any.
-    foreach (UMLObject *obj, m_objects) {
+    for(UMLObject  *obj : m_objects) {
         uIgnoreZeroPointer(obj);
         obj->saveToXMI (writer);
     }
     // Save associations if any.
-    foreach (UMLObject *obj, subordinates()) {
+    for(UMLObject *obj : subordinates()) {
         obj->saveToXMI (writer);
     }
     if (! Settings::optionState().generalState.uml2) {
@@ -298,7 +298,7 @@ void UMLFolder::saveContents(QXmlStreamWriter& writer)
             writer.writeAttribute(QStringLiteral("resolution"),
                                   QString::number(UMLApp::app()->document()->resolution()));
         }
-        foreach (UMLView* pView, m_diagrams) {
+        for(UMLView *pView : m_diagrams) {
             pView->umlScene()->saveToXMI(writer);
         }
         writer.writeEndElement();            // diagrams
@@ -448,11 +448,11 @@ bool UMLFolder::loadFolderFile(const QString& path)
 {
     QFile file(path);
     if (!file.exists()) {
-        KMessageBox::error(0, i18n("The folderfile %1 does not exist.", path), i18n("Load Error"));
+        KMessageBox::error(nullptr, i18n("The folderfile %1 does not exist.", path), i18n("Load Error"));
         return false;
     }
     if (!file.open(QIODevice::ReadOnly)) {
-        KMessageBox::error(0, i18n("The folderfile %1 cannot be opened.", path), i18n("Load Error"));
+        KMessageBox::error(nullptr, i18n("The folderfile %1 cannot be opened.", path), i18n("Load Error"));
         return false;
     }
     QTextStream stream(&file);
@@ -544,7 +544,7 @@ bool UMLFolder::load1(QDomElement& element)
                 continue;
             }
         }
-        UMLObject *pObject = 0;
+        UMLObject  *pObject = nullptr;
         // Avoid duplicate creation of forward declared object
         QString idStr = Model_Utils::getXmiId(tempElement);
         if (!idStr.isEmpty()) {
@@ -555,9 +555,9 @@ bool UMLFolder::load1(QDomElement& element)
             }
         }
         // Avoid duplicate creation of datatype
-        if (pObject == 0 && this == umldoc->datatypeFolder()) {
+        if (pObject == nullptr && this == umldoc->datatypeFolder()) {
             QString name = tempElement.attribute(QStringLiteral("name"));
-            foreach (UMLObject *o, m_objects) {
+            for(UMLObject *o : m_objects) {
                 uIgnoreZeroPointer(o);
                 if (o->name() == name) {
                     UMLDatatype *dt = o->asUMLDatatype();
@@ -570,7 +570,7 @@ bool UMLFolder::load1(QDomElement& element)
                 }
             }
         }
-        if (pObject == 0) {
+        if (pObject == nullptr) {
             QString stereoID = tempElement.attribute(QStringLiteral("stereotype"));
             pObject = Object_Factory::makeObjectFromXMI(type, stereoID);
             if (!pObject) {
