@@ -132,7 +132,7 @@ void UMLStereotype::saveToXMI(QXmlStreamWriter& writer)
         if (! Settings::optionState().generalState.uml2) {
             writer.writeStartElement(QStringLiteral("UML:Stereotype.feature"));
         }
-        foreach (AttributeDef ad, m_attrDefs) {
+        for(AttributeDef ad : m_attrDefs) {
             const QString tag = (Settings::optionState().generalState.uml2 ?
                                  QStringLiteral("ownedAttribute") : QStringLiteral("UML:Attribute"));
             writer.writeStartElement(tag);
@@ -231,8 +231,8 @@ int UMLStereotype::refCount() const
  */
 QString UMLStereotype::name(bool includeAdornments) const
 {
-    if (includeAdornments)
+    if (includeAdornments) {
         return QString::fromUtf8("«") + UMLObject::name() + QString::fromUtf8("»");
-    else
-        return UMLObject::name();
+    }
+    return UMLObject::name();
 }
