@@ -42,9 +42,9 @@ namespace Widget_Utils
      */
     UMLWidget* findWidget(Uml::ID::Type id,
                           const UMLWidgetList& widgets,
-                          const MessageWidgetList* messages /* = 0 */)
+                          const MessageWidgetList *messages /* = nullptr */)
     {
-        foreach (UMLWidget* obj, widgets) {
+        for(UMLWidget *obj : widgets) {
             if (obj->isObjectWidget()) {
                 if (obj->localID() == id)
                     return obj;
@@ -54,12 +54,12 @@ namespace Widget_Utils
         }
 
         if (messages) {
-            foreach (UMLWidget* obj, *messages) {
+            for(UMLWidget *obj : *messages) {
                 if (obj->id() == id)
                     return obj;
             }
         }
-        return 0;
+        return nullptr;
     }
 
     /**
@@ -425,7 +425,7 @@ namespace Widget_Utils
 
         stream.writeStartElement(QStringLiteral("stops"));
 
-        foreach (const QGradientStop& stop, gradient->stops()) {
+        for(const QGradientStop& stop : gradient->stops()) {
             stream.writeStartElement(QStringLiteral("stop"));
             stream.writeAttribute(QStringLiteral("position"), QString::number(stop.first));
             stream.writeAttribute(QStringLiteral("color"), stop.second.name());
@@ -469,7 +469,7 @@ namespace Widget_Utils
         else if(style == Qt::LinearGradientPattern
                 || style == Qt::RadialGradientPattern
                 || style == Qt::ConicalGradientPattern) {
-            QGradient *gradient = 0;
+            QGradient  *gradient = nullptr;
             QDomElement gradElement = qElement.firstChildElement(QStringLiteral("gradient"));
 
             if(!loadGradientFromXMI(gradElement, gradient) || !gradient) {
@@ -1050,7 +1050,7 @@ namespace Widget_Utils
      */
     void ensureNestedVisible(UMLWidget *self, UMLWidgetList widgetList)
     {
-        foreach (UMLWidget* other, widgetList) {
+        for(UMLWidget *other : widgetList) {
             if (other == self)
                 continue;
             if (other->isLocatedIn(self)) {
