@@ -18,10 +18,10 @@
 
 void TEST_classifier::test_equal()
 {
-    UMLClassifier* a = new UMLClassifier("Test A", Uml::ID::None);
+    UMLClassifier* a = new UMLClassifier(QStringLiteral("Test A"), Uml::ID::None);
     UMLClassifier* b = a;
-    UMLClassifier* c = new UMLClassifier("Test A", Uml::ID::None);
-    UMLClassifier* d = new UMLClassifier("Test B", Uml::ID::None);
+    UMLClassifier* c = new UMLClassifier(QStringLiteral("Test A"), Uml::ID::None);
+    UMLClassifier* d = new UMLClassifier(QStringLiteral("Test B"), Uml::ID::None);
     QCOMPARE(*a == *b, true);
     QCOMPARE(*a == *c, true);
     QCOMPARE(*b == *c, true);
@@ -30,25 +30,25 @@ void TEST_classifier::test_equal()
 
 void TEST_classifier::test_copyInto()
 {
-    UMLClassifier a("Test A", Uml::ID::None);
-    UMLClassifier b("Test B", Uml::ID::None);
+    UMLClassifier a(QStringLiteral("Test A"), Uml::ID::None);
+    UMLClassifier b(QStringLiteral("Test B"), Uml::ID::None);
     b.copyInto(&a);
     QCOMPARE(a == b, true);
 }
 
 void TEST_classifier::test_clone()
 {
-    UMLClassifier* a = new UMLClassifier("Test A", Uml::ID::None);
+    UMLClassifier* a = new UMLClassifier(QStringLiteral("Test A"), Uml::ID::None);
     UMLClassifier* b = a->clone()->asUMLClassifier();
     QCOMPARE(*a == *b, true);
 }
 
 void TEST_classifier::test_addAttributeWithType()
 {
-    UMLClassifier a("Test A", Uml::ID::None);
-    a.addAttribute("attributeA_", Uml::ID::None);
-    UMLAttribute *attrA = a.addAttribute("attributeA_", Uml::ID::None);
-    /* UMLAttribute* attrB = */ a.addAttribute("attributeB_", Uml::ID::None);
+    UMLClassifier a(QStringLiteral("Test A"), Uml::ID::None);
+    a.addAttribute(QStringLiteral("attributeA_"), Uml::ID::None);
+    UMLAttribute *attrA = a.addAttribute(QStringLiteral("attributeA_"), Uml::ID::None);
+    /* UMLAttribute* attrB = */ a.addAttribute(QStringLiteral("attributeB_"), Uml::ID::None);
     int num1 = a.getAttributeList().count();
     QCOMPARE(num1, 2);
     int num2 = a.removeAttribute(attrA);
@@ -69,13 +69,13 @@ void TEST_classifier::test_addAttributeWithAttribute()
 
 void TEST_classifier::test_removeAndCountAttribute()
 {
-    UMLClassifier* a = new UMLClassifier("Test A", Uml::ID::None);
+    UMLClassifier* a = new UMLClassifier(QStringLiteral("Test A"), Uml::ID::None);
     int num0 = a->getAttributeList().count();
     QCOMPARE(num0, 0);  // no attributes present yet
-    /*UMLAttribute* attrA = */ a->addAttribute("attributeA_", Uml::ID::None);
-    UMLAttribute* attrB = a->addAttribute("attributeB_", Uml::ID::None);
-    UMLAttribute* attrC = a->addAttribute("attributeC_", Uml::ID::None);
-    /* UMLAttribute* attrD = */ a->addAttribute("attributeD_", Uml::ID::None);
+    /*UMLAttribute* attrA = */ a->addAttribute(QStringLiteral("attributeA_"), Uml::ID::None);
+    UMLAttribute* attrB = a->addAttribute(QStringLiteral("attributeB_"), Uml::ID::None);
+    UMLAttribute* attrC = a->addAttribute(QStringLiteral("attributeC_"), Uml::ID::None);
+    /* UMLAttribute* attrD = */ a->addAttribute(QStringLiteral("attributeD_"), Uml::ID::None);
     int num1 = a->getAttributeList().count();
     QCOMPARE(num1, 4);
     int num2 = a->removeAttribute(attrB);
@@ -163,24 +163,24 @@ void TEST_classifier::test_resolveRef()
 
 void TEST_classifier::test_findOperations()
 {
-    UMLClassifier c("Test A", Uml::ID::None);
-    UMLOperation o1(nullptr, "testop1");
+    UMLClassifier c(QStringLiteral("Test A"), Uml::ID::None);
+    UMLOperation o1(nullptr, QStringLiteral("testop1"));
     c.addOperation(&o1);
     int num1 = c.getOpList().count();
     QCOMPARE(num1, 1);
-    UMLOperation o2(nullptr, "testop2");
+    UMLOperation o2(nullptr, QStringLiteral("testop2"));
     c.addOperation(&o2);
     int num2 = c.getOpList().count();
     QCOMPARE(num2, 2);
-    QCOMPARE(c.findOperations("testop1").count(), 1);
-    QCOMPARE(c.findOperations("testop2").count(), 1);
-    QCOMPARE(c.findOperations("testOp1").count(), 0);
-    QCOMPARE(c.findOperations("testOp2").count(), 0);
+    QCOMPARE(c.findOperations(QStringLiteral("testop1")).count(), 1);
+    QCOMPARE(c.findOperations(QStringLiteral("testop2")).count(), 1);
+    QCOMPARE(c.findOperations(QStringLiteral("testOp1")).count(), 0);
+    QCOMPARE(c.findOperations(QStringLiteral("testOp2")).count(), 0);
     // case insensitive language
     Uml::ProgrammingLanguage::Enum lang = UMLApp::app()->activeLanguage();
     UMLApp::app()->setActiveLanguage(Uml::ProgrammingLanguage::PostgreSQL);
-    QCOMPARE(c.findOperations("testOp1").count(), 1);
-    QCOMPARE(c.findOperations("testOp2").count(), 1);
+    QCOMPARE(c.findOperations(QStringLiteral("testOp1")).count(), 1);
+    QCOMPARE(c.findOperations(QStringLiteral("testOp2")).count(), 1);
     UMLApp::app()->setActiveLanguage(lang);
 }
 
@@ -191,33 +191,33 @@ void TEST_classifier::test_findChildObjectById()
 
 void TEST_classifier::test_findOperation()
 {
-    UMLClassifier c("Test A", Uml::ID::None);
-    UMLOperation o1(nullptr, "testop1");
-    UMLAttribute a1(nullptr, "aParam");
-    a1.setTypeName("int");
+    UMLClassifier c(QStringLiteral("Test A"), Uml::ID::None);
+    UMLOperation o1(nullptr, QStringLiteral("testop1"));
+    UMLAttribute a1(nullptr, QStringLiteral("aParam"));
+    a1.setTypeName(QStringLiteral("int"));
     o1.addParm(&a1);
     c.addOperation(&o1);
-    UMLOperation o2(nullptr, "testop1");
-    UMLAttribute a2(nullptr, "aParam");
-    a2.setTypeName("double");
+    UMLOperation o2(nullptr, QStringLiteral("testop1"));
+    UMLAttribute a2(nullptr, QStringLiteral("aParam"));
+    a2.setTypeName(QStringLiteral("double"));
     o2.addParm(&a2);
     c.addOperation(&o2);
     Model_Utils::NameAndType_List searchTypes;
     // first function
-    searchTypes << Model_Utils::NameAndType("aParam", a1.getType());
-    UMLOperation *o = c.findOperation("testop1", searchTypes);
+    searchTypes << Model_Utils::NameAndType(QStringLiteral("aParam"), a1.getType());
+    UMLOperation *o = c.findOperation(QStringLiteral("testop1"), searchTypes);
     QVERIFY(o);
     // second function
     searchTypes.clear();
-    searchTypes << Model_Utils::NameAndType("aParam", a2.getType());
-    o = c.findOperation("testop1", searchTypes);
+    searchTypes << Model_Utils::NameAndType(QStringLiteral("aParam"), a2.getType());
+    o = c.findOperation(QStringLiteral("testop1"), searchTypes);
     QVERIFY(o);
 
     // unknown type
-    UMLDatatype d1("someType");
+    UMLDatatype d1(QStringLiteral("someType"));
     searchTypes.clear();
-    searchTypes << Model_Utils::NameAndType("aParam", &d1);
-    o = c.findOperation("testop1", searchTypes);
+    searchTypes << Model_Utils::NameAndType(QStringLiteral("aParam"), &d1);
+    o = c.findOperation(QStringLiteral("testop1"), searchTypes);
     QVERIFY(!o);
 
 #if 0
@@ -239,8 +239,8 @@ void TEST_classifier::test_findOperation()
 
 void TEST_classifier::test_findSuperClassConcepts()
 {
-    UMLClassifier c1("Test A");
-    UMLClassifier c2("Test B");
+    UMLClassifier c1(QStringLiteral("Test A"));
+    UMLClassifier c2(QStringLiteral("Test B"));
     UMLAssociation a1(Uml::AssociationType::Generalization, &c1, &c2);
     QCOMPARE(c1.findSuperClassConcepts(UMLClassifier::ALL).size(), 0);
     c1.addAssociationEnd(&a1);
@@ -252,8 +252,8 @@ void TEST_classifier::test_findSuperClassConcepts()
 
 void TEST_classifier::test_findSubClassConcepts()
 {
-    UMLClassifier c1("Test A");
-    UMLClassifier c2("Test B");
+    UMLClassifier c1(QStringLiteral("Test A"));
+    UMLClassifier c2(QStringLiteral("Test B"));
     UMLAssociation a1(Uml::AssociationType::Generalization, &c1, &c2);
     QCOMPARE(c2.findSubClassConcepts(UMLClassifier::ALL).size(), 0);
     c2.addAssociationEnd(&a1);
@@ -270,7 +270,7 @@ void TEST_classifier::test_setGetClassAssoc()
 
 void TEST_classifier::test_isInterface()
 {
-    UMLClassifier c1("Test A");
+    UMLClassifier c1(QStringLiteral("Test A"));
     QCOMPARE(c1.isInterface(), false);
     c1.setBaseType(UMLObject::ObjectType::ot_Interface);
     QCOMPARE(c1.isInterface(), true);
@@ -307,12 +307,12 @@ typedef TestUML<UMLClassifier, const QString&> TestUMLClassifier;
 
 void TEST_classifier::test_saveAndLoad()
 {
-    UMLPackage parent("test package");
-    TestUMLClassifier c1("Test A");
+    UMLPackage parent(QStringLiteral("test package"));
+    TestUMLClassifier c1(QStringLiteral("Test A"));
     c1.setUMLPackage(&parent);
-    UMLOperation o1(nullptr, "testop1");
+    UMLOperation o1(nullptr, QStringLiteral("testop1"));
     c1.addOperation(&o1);
-    UMLOperation o2(nullptr, "testop2");
+    UMLOperation o2(nullptr, QStringLiteral("testop2"));
     c1.addOperation(&o2);
     QString save = c1.testSave1();
     //c1.testDump("save");
